@@ -1,6 +1,6 @@
 /***************************************************************************
  *   Copyright (C) 2004 by Roberto Virga                                   *
- *   rvirga@users.sf.net                                                   *
+ *   rvirga@users.sourceforge.net                                          *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -41,7 +41,7 @@
 #include <kbspanel.h>
 #include <kbspanelview.h>
 #include <kbspreferences.h>
-#include <kbsprojectdialog.h>
+#include <kbsprojectwizard.h>
 #include <kbsprojectnode.h>
 #include <kbsprojectplugin.h>
 #include <kbsproxydialog.h>
@@ -50,9 +50,10 @@
 #include <kbstransferview.h>
 #include <kbstreeview.h>
 #include <kbsview.h>
+#include <kbswebtoolbar.h>
 #include <kbsworkunitnode.h>
 
-#include <boincdata.h>
+#include <kbsboincdata.h>
 
 #include "kboincspy.h"
 
@@ -63,20 +64,16 @@ KBoincSpy::KBoincSpy()
            m_document(new KBSDocument(this)),
            m_view(new KBSView(m_document, this)),
            m_tray(new KBSSystemTray(this)),
+           m_toolbar(NULL),
            m_show(false), m_close(false),
            m_host(NULL), m_project(NULL), m_workunit(NULL), m_panel(NULL)
 {
   if(NULL == kmain) kmain = this;
   
   setCentralWidget(m_view);
-  
   setupActions();
-  
   setAutoSaveSettings("KBoincSpy", false);
   
-  m_messages.setAutoDelete(true);
-  m_transfers.setAutoDelete(true);
-  
   connect(m_document, SIGNAL(childRemoved(KBSTreeNode *)), this, SLOT(removeViews(KBSTreeNode *)));
   
   connect(m_view, SIGNAL(currentTreeViewChanged()), this, SLOT(updateTreeViewSelection()));
@@ -85,7 +82,7 @@ KBoincSpy::KBoincSpy()
     connect(m_view->treeView(KBSView::TreeView(treeView)), SIGNAL(selectionChanged()),
             this, SLOT(updateTreeViewSelection()));
   
-  for(unsigned panelView = KBSView::SimpleView; panelView <= KBSView::TabbedView; ++panelView)        
+  for(unsigned panelView = KBSView::SimpleView; panelView <= KBSView::TabbedView; ++panelView) 
     connect(m_view->panelView(KBSView::PanelView(panelView)), SIGNAL(currentPanelChanged()),
             this, SLOT(updatePanelVisible()));
   
@@ -96,8 +93,17 @@ KBoincSpy::KBoincSpy()
 
 KBoincSpy::~KBoincSpy()
 {
-  for(QPtrDictIterator<KBSMessageView> it(m_messages); it.current() != NULL; ++it)
+  for(QPtrDictIterator<KBSMessageView> it(m_messages); it.current() != NULL; ++it) {
     it.current()->close();
+    delete it.current();
+  }
+  m_messages.clear();
+  
+  for(QPtrDictIterator<KBSTransferView> it(m_transfers); it.current() != NULL; ++it) {
+    it.current()->close();
+    delete it.current();
+  }
+  m_transfers.clear();
 }
 
 KBSDocument *KBoincSpy::document() const
@@ -209,7 +215,7 @@ bool KBoincSpy::queryClose()
 
 void KBoincSpy::setupActions()
 {
-  setStandardToolBarMenuEnabled(false);
+  setStandardToolBarMenuEnabled(true);
   
   new KAction(i18n("&Add Location..."), KStdAccel::shortcut(KStdAccel::Open),
               this, SLOT(locationAdd()), actionCollection(), "location_add");
@@ -258,6 +264,9 @@ void KBoincSpy::setupActions()
   icon_huge->setExclusiveGroup("iconsize");
   
   
+  new KAction(i18n("Run &Benchmarks"), 0, this, SLOT(runBenchmarks()),
+              actionCollection(), "run_benchmarks");
+  
   run_auto = new KRadioAction(i18n("Run Based on &Preferences"), 0,
                               this, SLOT(activateRunAuto()),
                               actionCollection(), "run_auto");
@@ -305,7 +314,7 @@ void KBoincSpy::setupActions()
                               actionCollection(), "project_reset");
   project_actions.append(project_reset);
   
-  project_detach = new KAction(i18n("&Detach From Project"), 0,
+  project_detach = new KAction(i18n("&Detach from Project"), 0,
                                this, SLOT(projectDetach()),
                                actionCollection(), "project_detach");
   project_actions.append(project_detach);
@@ -353,10 +362,11 @@ void KBoincSpy::setupActions()
   activateTreeView();
   activateSmallIcons();
   
-  updateTreeViewSelection();  
-  updatePanelVisible();  
+  updateTreeViewSelection();
+  updatePanelVisible();
   
-  toolBar()->hide();
+  delete toolBar();
+  m_toolbar = new KBSWebToolBar(this, "webToolBar");
 }
 
 void KBoincSpy::readGeometry(KConfig *config, const QString &group)
@@ -411,6 +421,8 @@ void KBoincSpy::locationRemove()
   const QString message = i18n("Are you sure you want to remove this location?");
   if(KMessageBox::warningYesNo(this, message) == KMessageBox::Yes) 
     m_document->disconnectFrom(m_host->monitor()->location());
+  
+  m_host = NULL;
 }
 
 void KBoincSpy::editCopy()
@@ -509,8 +521,7 @@ void KBoincSpy::clientMessages()
   
   KBSMessageView *view = m_messages.find(m_host);
   
-  if(NULL == view)
-  {
+  if(NULL == view) {
     view = new KBSMessageView(m_host->monitor(), this, m_host->name());
     m_messages.insert(m_host, view);
   }
@@ -524,8 +535,7 @@ void KBoincSpy::fileTransfers()
 
   KBSTransferView *view = m_transfers.find(m_host);
 
-  if(NULL == view)
-  {
+  if(NULL == view) {
     view = new KBSTransferView(m_host->monitor(), this, m_host->name());
     m_transfers.insert(m_host, view);
   }
@@ -543,13 +553,20 @@ void KBoincSpy::activateNetworkConnect()
     m_host->monitor()->rpcMonitor()->setNetworkMode(ConnectAlways);
 }
 
+void KBoincSpy::runBenchmarks()
+{
+  if(NULL == m_host) return;
+  
+  m_host->monitor()->rpcMonitor()->runBenchmarks();
+}
+
 void KBoincSpy::networkProxy()
 {
   if(NULL == m_host) return;
   
   KBSProxyDialog *dialog = new KBSProxyDialog(this);
   
-  const BOINCClientState *state = m_host->monitor()->state();
+  const KBSBOINCClientState *state = m_host->monitor()->state();
   if(NULL != state)
   {
     dialog->socks->setChecked(!state->proxy_info.socks.server.name.isEmpty());
@@ -568,7 +585,7 @@ void KBoincSpy::networkProxy()
   
   if(dialog->exec() == KDialog::Accepted)
   {
-    BOINCProxyInfo proxy_info;
+    KBSBOINCProxyInfo proxy_info;
     
     proxy_info.socks.server.name = dialog->socks->isChecked() ? dialog->socks_server->text()
                                                               : QString::null;
@@ -599,11 +616,8 @@ void KBoincSpy::projectAttach()
 {
   if(NULL == m_host) return;
   
-  KBSProjectDialog *dialog = new KBSProjectDialog(this);
-  if(dialog->exec() == KDialog::Accepted)
-    m_host->monitor()->rpcMonitor()->attachProject(dialog->project->text(),
-                                                   dialog->account->text());
-  delete dialog;
+  KBSProjectWizard wizard(m_host->monitor(), this);
+  wizard.exec();
 }
 
 void KBoincSpy::projectDetach()
@@ -613,7 +627,7 @@ void KBoincSpy::projectDetach()
   const QString message = i18n("Are you sure you want to detach host %1\nfrom project %2?")
                             .arg(m_host->name()).arg(m_project->name());
   if(KMessageBox::warningYesNo(this, message) == KMessageBox::Yes) 
-    m_host->monitor()->rpcMonitor()->detachProject(formatProjectName(m_project->project()));
+    m_host->monitor()->rpcMonitor()->detachProject(m_project->projectURL());
 }
 
 void KBoincSpy::projectReset()
@@ -623,21 +637,21 @@ void KBoincSpy::projectReset()
   const QString message = i18n("Are you sure you want to reset project %2\non host %1?")
                             .arg(m_host->name()).arg(m_project->name());
   if(KMessageBox::warningYesNo(this, message) == KMessageBox::Yes) 
-    m_host->monitor()->rpcMonitor()->resetProject(formatProjectName(m_project->project()));
+    m_host->monitor()->rpcMonitor()->resetProject(m_project->projectURL());
 }
 
 void KBoincSpy::projectUpdate()
 {
   if(NULL == m_host || NULL == m_project) return;
   
-  m_host->monitor()->rpcMonitor()->updateProject(formatProjectName(m_project->project()));
+  m_host->monitor()->rpcMonitor()->updateProject(m_project->projectURL());
 }
 
 void KBoincSpy::activateProjectSuspend()
 {
   if(NULL == m_host || NULL == m_project) return;
   
-  m_host->monitor()->rpcMonitor()->suspendProject(formatProjectName(m_project->project()),
+  m_host->monitor()->rpcMonitor()->suspendProject(m_project->projectURL(),
                                                   !m_project->isSuspended());
 }
 
@@ -645,7 +659,7 @@ void KBoincSpy::activateProjectExtinguish()
 {
   if(NULL == m_host || NULL == m_project) return;
   
-  m_host->monitor()->rpcMonitor()->extinguishProject(formatProjectName(m_project->project()),
+  m_host->monitor()->rpcMonitor()->extinguishProject(m_project->projectURL(),
                                                      project_extinguish->isChecked());
 }
 
@@ -653,7 +667,7 @@ void KBoincSpy::showGraphics()
 {
   if(NULL == m_host || NULL == m_workunit) return;
   
-  m_host->monitor()->rpcMonitor()->showGraphics(formatProjectName(m_workunit->project()),
+  m_host->monitor()->rpcMonitor()->showGraphics(m_workunit->projectURL(),
                                                 m_workunit->result());
 }
 
@@ -663,15 +677,14 @@ void KBoincSpy::resultAbort()
   
   const QString message = i18n("Are you sure you want to abort workunit %2\non host %1?")
                             .arg(m_host->name()).arg(m_workunit->name());
-  m_host->monitor()->rpcMonitor()->abortResult(formatProjectName(m_workunit->project()),
-                                               m_workunit->result());
+  m_host->monitor()->rpcMonitor()->abortResult(m_workunit->project(), m_workunit->result());
 }
 
 void KBoincSpy::activateResultSuspend()
 {
   if(NULL == m_host || NULL == m_workunit) return;
   
-  m_host->monitor()->rpcMonitor()->suspendResult(formatProjectName(m_workunit->project()),
+  m_host->monitor()->rpcMonitor()->suspendResult(m_workunit->projectURL(),
                                                  m_workunit->result(),
                                                  !m_workunit->isSuspended());
 }
@@ -728,12 +741,14 @@ void KBoincSpy::removeViews(KBSTreeNode *host)
   if(NULL != messageView) {
     messageView->close();
     m_messages.remove(host);
+    delete messageView;
   }
 
   KBSTransferView *transferView = m_transfers.find(host);
   if(NULL != transferView) {
     transferView->close();
     m_transfers.remove(host);
+    delete transferView;
   }
 }
 
@@ -794,7 +809,7 @@ void KBoincSpy::updateTreeViewSelection()
     plugActionList("node_actions", result_actions);
   else if(NULL != m_project)
     plugActionList("node_actions", project_actions);
-    
+  
   if(NULL != m_host)
   {
     updateRunMode();
@@ -821,6 +836,9 @@ void KBoincSpy::updateTreeViewSelection()
     connect(m_workunit, SIGNAL(nodeChanged(KBSTreeNode *)),
             this, SLOT(updateResultState(KBSTreeNode *)));
   }
+  
+  if(NULL != m_toolbar)
+    m_toolbar->setMonitor(m_host ? m_host->monitor() : NULL);
 }
 
 void KBoincSpy::updatePanelVisible()
@@ -835,8 +853,8 @@ void KBoincSpy::updatePanelVisible()
 
 void KBoincSpy::updateRunMode()
 {
-  BOINCRunMode runMode = (NULL != m_host) ? m_host->monitor()->rpcMonitor()->runMode()
-                                          : RunAuto;
+  KBSBOINCRunMode runMode = (NULL != m_host) ? m_host->monitor()->rpcMonitor()->runMode()
+                                             : RunAuto;
   
   switch(runMode) {
     case RunAlways:
@@ -853,8 +871,8 @@ void KBoincSpy::updateRunMode()
 
 void KBoincSpy::updateNetworkMode()
 {
-  BOINCNetworkMode networkMode = (NULL != m_host) ? m_host->monitor()->rpcMonitor()->networkMode()
-                                                  : ConnectAlways;
+  KBSBOINCNetworkMode networkMode = (NULL != m_host) ? m_host->monitor()->rpcMonitor()->networkMode()
+                                                     : ConnectAlways;
   
   network_connect->setChecked(ConnectNever == networkMode);
 }
