@@ -1,24 +1,24 @@
 /***************************************************************************
  *   Copyright (C) 2004 by Roberto Virga                                   *
- *   rvirga@users.sf.net                                                   *
+ *   rvirga@users.sourceforge.net                                          *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
+ *   it under the terms of the GNU Library General Public License as       *
+ *   published by the Free Software Foundation; either version 2 of the    *
+ *   License, or (at your option) any later version.                       *
  *                                                                         *
  *   This program is distributed in the hope that it will be useful,       *
  *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
  *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
  *   GNU General Public License for more details.                          *
  *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program; if not, write to the                         *
+ *   You should have received a copy of the GNU Library General Public     *
+ *   License along with this program; if not, write to the                 *
  *   Free Software Foundation, Inc.,                                       *
  *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
  ***************************************************************************/
 
-#include <qsocket.h>
+#include <unistd.h>
 
 #include <kapplication.h>
 #include <klocale.h>
@@ -32,13 +32,23 @@
 #include <kbstaskmonitor.h>
 #include <kbstree.h>
 
-const QString BOINCClientStateFile = "client_state.xml";
+using namespace KBSBOINC;
 
-const QString BOINCAccountFilePrefix = "account_";
-const QString BOINCAccountFileSuffix = ".xml";
+const QString KBSBOINCClientStateFile = "client_state.xml";
 
-const unsigned BOINCAccountFilePrefixLength = BOINCAccountFilePrefix.length();
-const unsigned BOINCAccountFileSuffixLength = BOINCAccountFileSuffix.length();
+const QString KBSBOINCRPCAuthenticationFile = "gui_rpc_auth.cfg";
+
+const QString KBSBOINCAccountFilePrefix = "account_";
+const QString KBSBOINCAccountFileSuffix = ".xml";
+
+const unsigned KBSBOINCAccountFilePrefixLength = KBSBOINCAccountFilePrefix.length();
+const unsigned KBSBOINCAccountFileSuffixLength = KBSBOINCAccountFileSuffix.length();
+
+const QString KBSBOINCStatisticsFilePrefix = "statistics_";
+const QString KBSBOINCStatisticsFileSuffix = ".xml";
+
+const unsigned KBSBOINCStatisticsFilePrefixLength = KBSBOINCStatisticsFilePrefix.length();
+const unsigned KBSBOINCStatisticsFileSuffixLength = KBSBOINCStatisticsFileSuffix.length();
 
 QString KBSLocation::defaultHost(const KURL &url)
 {
@@ -60,21 +70,18 @@ bool operator==(const KBSLocation &location1, const KBSLocation &location2)
 
 KBSBOINCMonitor::KBSBOINCMonitor(const KBSLocation &location, KBSTreeNode *parent, const char *name)
                : KBSDataMonitor(location.url, parent, name), m_location(location),
-                 m_rpcMonitor(new KBSRPCMonitor(location.host, this)), m_startup(true)
+                 m_rpcMonitor(new KBSRPCMonitor(location.host, this)), m_client(NULL),
+                 m_startup(true), m_killClient(false)
 {
   m_rpcMonitor->setPort(location.port);
   
-  m_accounts.setAutoDelete(true);
-  m_projectMonitors.setAutoDelete(true);
-  m_taskMonitors.setAutoDelete(true);
-  
   connect(this, SIGNAL(fileUpdated(const QString &)),
           this, SLOT(updateFile(const QString &)));
-          
+  
   connect(this, SIGNAL(projectsAdded(const QStringList &)),
-          this, SLOT(addAccounts(const QStringList &)));
+          this, SLOT(addProjectFiles(const QStringList &)));
   connect(this, SIGNAL(projectsRemoved(const QStringList &)),
-          this, SLOT(removeAccounts(const QStringList &)));
+          this, SLOT(removeProjectFiles(const QStringList &)));
   
   connect(this, SIGNAL(projectsAdded(const QStringList &)),
           this, SLOT(addProjectMonitors(const QStringList &)));
@@ -84,7 +91,37 @@ KBSBOINCMonitor::KBSBOINCMonitor(const KBSLocation &location, KBSTreeNode *paren
   connect(this, SIGNAL(resultActivated(unsigned, const QString &, bool)),
           this, SLOT(updateTaskMonitor(unsigned, const QString &, bool)));
   
-  addFile(BOINCClientStateFile);
+  addFile(KBSBOINCClientStateFile);
+  addFile(KBSBOINCRPCAuthenticationFile);
+}
+
+KBSBOINCMonitor::~KBSBOINCMonitor()
+{
+  for(QIntDictIterator<KBSTaskMonitor> it(m_taskMonitors); it.current() != NULL; ++it)
+    delete it.current();
+  m_taskMonitors.clear();
+  
+  for(QDictIterator<KBSProjectMonitor> it(m_projectMonitors); it.current() != NULL; ++it)
+    delete it.current();
+  m_projectMonitors.clear();
+  
+  for(QDictIterator<KBSBOINCAccount> it(m_accounts); it.current() != NULL; ++it)
+    delete it.current();
+  m_accounts.clear();
+  
+  for(QDictIterator<KBSBOINCProjectStatistics> it(m_statistics); it.current() != NULL; ++it)
+    delete it.current();
+  m_statistics.clear();
+  
+  if(!m_killClient || !m_client->isRunning()) return;
+  
+  if(m_rpcMonitor->canRPC())
+    m_rpcMonitor->quit();
+  
+  // failsafe method
+  m_client->tryTerminate();
+  usleep(200);
+  m_client->tryTerminate();
 }
 
 bool KBSBOINCMonitor::isLocal() const
@@ -97,119 +134,131 @@ KBSLocation KBSBOINCMonitor::location() const
   return m_location;
 }
 
-const BOINCClientState *KBSBOINCMonitor::state() const
+void KBSBOINCMonitor::exec(const QString &client, bool killOnExit)
 {
-  return file(BOINCClientStateFile)->ok ? &m_state : NULL;
-}
-    
-const BOINCAccount *KBSBOINCMonitor::account(const QString &project) const
-{
-  return file(formatFileName(project))-> ok ? m_accounts.find(project) : NULL;
+  if(NULL != m_client || !isLocal()) return;
+  
+  m_client = new QProcess(this);
+  
+  m_client->setWorkingDirectory(m_location.url.path(+1));
+  
+  const KURL executable(m_location.url, client);
+  m_client->addArgument(executable.path(-1));
+  
+  m_client->start();
+  
+  m_killClient = killOnExit;
 }
 
-QString KBSBOINCMonitor::project(const BOINCProject &project) const
+const KBSBOINCClientState *KBSBOINCMonitor::state() const
+{
+  return file(KBSBOINCClientStateFile)->ok ? &m_state : NULL;
+}
+    
+const KBSBOINCAccount *KBSBOINCMonitor::account(const QString &project) const
+{
+  return file(formatAccountFileName(project))->ok ? m_accounts.find(project) : NULL;
+}
+
+const KBSBOINCProjectStatistics *KBSBOINCMonitor::statistics(const QString &project) const
+{
+  return file(formatStatisticsFileName(project))->ok ? m_statistics.find(project) : NULL;
+}
+
+QString KBSBOINCMonitor::project(const KBSBOINCProject &project) const
 {
   return parseProjectName(project.master_url);
 }
 
-QString KBSBOINCMonitor::project(const BOINCApp &app) const
+QString KBSBOINCMonitor::project(const KBSBOINCApp &app) const
 {
-  if(!m_state.app_version.contains(app.name) || m_state.app_version[app.name].isEmpty())
-    return QString::null;
+  double max = 0.0;
+  QString out = QString::null;
   
-  BOINCAppVersion app_version = m_state.app_version[app.name].first();
-  
-  QStringList domains;
-  for(QValueList<BOINCFileRef>::const_iterator file_ref = app_version.file_ref.begin();
-      file_ref != app_version.file_ref.end(); ++file_ref)
+  const KURL::List urls = collectURLs(app);
+  for(KURL::List::const_iterator url = urls.begin(); url != urls.end(); ++url)
   {
-    if(!m_state.file_info.contains((*file_ref).file_name)) continue;
+    if(!(*url).isValid()) continue;
     
-    const QValueList<KURL> urls = m_state.file_info[(*file_ref).file_name].url;
-    for(QValueList<KURL>::const_iterator url = urls.begin(); url != urls.end(); ++url)
+    for(QMap<QString,KBSBOINCProject>::const_iterator project = m_state.project.begin();
+        project != m_state.project.end(); ++project)
     {
-      if(!(*url).isValid()) continue;
-      
-      QString domain = (*url).host();
-      while(domain.contains('.') > 1)
-        domain = domain.mid(domain.find('.') + 1);
-      domains << domain;
+      const double score = matchURL(*url, (*project).scheduler_url);
+      if(score > max) { max = score; out = project.key(); }
     }
   }
-  if(domains.isEmpty()) return QString::null;
-
-  QValueList<BOINCProject> projects = m_state.project.values();
-  for(QValueList<BOINCProject>::const_iterator project = projects.begin();
-      project != projects.end(); ++project)
-    for(QStringList::const_iterator domain = domains.begin();
-        domain != domains.end(); ++domain)
-      if((*project).scheduler_url.host().endsWith(*domain))
-        return this->project(*project);
   
-  return QString::null;
+  return out;
 }
-    
-QString KBSBOINCMonitor::project(const BOINCWorkunit &workunit) const
+
+QString KBSBOINCMonitor::project(const KBSBOINCWorkunit &workunit) const
 {
-  QStringList domains;
-  for(QValueList<BOINCFileRef>::const_iterator file_ref = workunit.file_ref.begin();
-      file_ref != workunit.file_ref.end(); ++file_ref)
+  double max = 0.0;
+  QString out = QString::null;
+  
+  const KURL::List urls = collectURLs(workunit);
+  for(KURL::List::const_iterator url = urls.begin(); url != urls.end(); ++url)
   {
-    if(!m_state.file_info.contains((*file_ref).file_name)) continue;
+    if(!(*url).isValid()) continue;
     
-    const QValueList<KURL> urls = m_state.file_info[(*file_ref).file_name].url;
-    for(QValueList<KURL>::const_iterator url = urls.begin(); url != urls.end(); ++url)
+    for(QMap<QString,KBSBOINCProject>::const_iterator project = m_state.project.begin();
+        project != m_state.project.end(); ++project)
     {
-      if(!(*url).isValid()) continue;
-      
-      QString domain = (*url).host();
-      while(domain.contains('.') > 1)
-        domain = domain.mid(domain.find('.') + 1);
-      domains << domain;
+      const double score = matchURL(*url, (*project).scheduler_url);
+      if(score > max) { max = score; out = project.key(); }
     }
   }
-  if(domains.isEmpty()) return this->project(m_state.app[workunit.app_name]);
   
-  QValueList<BOINCProject> projects = m_state.project.values();
-  for(QValueList<BOINCProject>::const_iterator project = projects.begin();
-      project != projects.end(); ++project)
-    for(QStringList::const_iterator domain = domains.begin();
-        domain != domains.end(); ++domain)
-      if((*project).scheduler_url.host().endsWith(*domain))
-        return this->project(*project);
-  
-  return this->project(m_state.app[workunit.app_name]);
+  return out;
 }
 
-QString KBSBOINCMonitor::project(const BOINCResult &result) const
+QString KBSBOINCMonitor::project(const KBSBOINCResult &result) const
 {
-  if(m_state.workunit.contains(result.wu_name))
-    return project(m_state.workunit[result.wu_name]);
-  else
-    return QString::null;
+  double max = 0.0;
+  QString out = QString::null;
+  
+  const KURL::List urls = collectURLs(result);
+  for(KURL::List::const_iterator url = urls.begin(); url != urls.end(); ++url)
+  {
+    if(!(*url).isValid()) continue;
+    
+    for(QMap<QString,KBSBOINCProject>::const_iterator project = m_state.project.begin();
+        project != m_state.project.end(); ++project)
+    {
+      const double score = matchURL(*url, (*project).scheduler_url);
+      if(score > max) { max = score; out = project.key(); }
+    }
+  }
+  
+  return out;
 }
 
-QString KBSBOINCMonitor::project(const BOINCActiveTask &task) const
+QString KBSBOINCMonitor::project(const KBSBOINCActiveTask &task) const
 {
   return parseProjectName(task.project_master_url);
 }
 
-QString KBSBOINCMonitor::project(const BOINCAccount &account) const
+QString KBSBOINCMonitor::project(const KBSBOINCAccount &account) const
 {
   return parseProjectName(account.master_url);
 }
 
-QString KBSBOINCMonitor::app(const BOINCApp &app) const
+QString KBSBOINCMonitor::project(const KBSBOINCProjectStatistics &statistics) const
+{
+  return parseProjectName(statistics.master_url);
+}
+
+QString KBSBOINCMonitor::app(const KBSBOINCApp &app) const
 {
   return app.name;
 }
 
-QString KBSBOINCMonitor::app(const BOINCWorkunit &workunit) const
+QString KBSBOINCMonitor::app(const KBSBOINCWorkunit &workunit) const
 {
   return workunit.app_name;
 }
 
-QString KBSBOINCMonitor::app(const BOINCResult &result) const
+QString KBSBOINCMonitor::app(const KBSBOINCResult &result) const
 {
   if(m_state.workunit.contains(result.wu_name))
     return app(m_state.workunit[result.wu_name]);
@@ -217,7 +266,7 @@ QString KBSBOINCMonitor::app(const BOINCResult &result) const
     return QString::null;
 }
 
-QString KBSBOINCMonitor::app(const BOINCActiveTask &task) const
+QString KBSBOINCMonitor::app(const KBSBOINCActiveTask &task) const
 {
   if(m_state.result.contains(task.result_name))
     return app(m_state.result[task.result_name]);
@@ -225,30 +274,30 @@ QString KBSBOINCMonitor::app(const BOINCActiveTask &task) const
     return QString::null;
 }
     
-QString KBSBOINCMonitor::workunit(const BOINCWorkunit &workunit) const
+QString KBSBOINCMonitor::workunit(const KBSBOINCWorkunit &workunit) const
 {
   return workunit.name;
 }
 
-QString KBSBOINCMonitor::workunit(const BOINCResult &result) const
+QString KBSBOINCMonitor::workunit(const KBSBOINCResult &result) const
 {
   return result.wu_name;
 }
 
-QString KBSBOINCMonitor::workunit(const BOINCActiveTask &task) const
+QString KBSBOINCMonitor::workunit(const KBSBOINCActiveTask &task) const
 {
   if(m_state.result.contains(task.result_name))
     return workunit(m_state.result[task.result_name]);
   else
     return QString::null;
 }
-    
-QString KBSBOINCMonitor::result(const BOINCResult &result) const
+
+QString KBSBOINCMonitor::result(const KBSBOINCResult &result) const
 {
   return result.name;
 }
 
-QString KBSBOINCMonitor::result(const BOINCActiveTask &task) const
+QString KBSBOINCMonitor::result(const KBSBOINCActiveTask &task) const
 {
   return task.result_name;
 }
@@ -272,36 +321,85 @@ bool KBSBOINCMonitor::parseFile(KBSFileInfo *file, const QString &fileName)
 {
   qDebug("Parsing file %s...", file->fileName.latin1());
   
-  QDomDocument document(file->fileName);
-  if(!readFile(fileName, document)) return false;
-  
-  if(BOINCClientStateFile == file->fileName)
-    return parseClientStateDocument(document);
-  else {
-    const QString project = parseFileName(file->fileName);
-    if(project.isNull()) return false;
-   
-    BOINCAccount *account = m_accounts.find(project);
-    if(NULL == account) return false;
+  if(KBSBOINCClientStateFile == file->fileName)
+  {
+    QDomDocument document(file->fileName);
+    if(!readFile(fileName, document)) return false;
     
-    return parseAccountDocument(document, *account);
-  } 
+    return parseClientStateDocument(document);
+  }
+  else if(KBSBOINCRPCAuthenticationFile == file->fileName)
+  {
+    QStringList lines;
+    if(!readFile(fileName, lines)) return false;
+    
+    const QString password = (lines.count() > 0) ? lines[0].stripWhiteSpace() : "";
+    m_rpcMonitor->setPassword(password);
+    
+    qDebug("... parse OK");
+    
+    return true;
+  }
+  else
+  {
+    QString project;
+
+    project = parseAccountFileName(file->fileName);
+    if(!project.isNull())
+    {
+      KBSBOINCAccount *account = m_accounts.find(project);
+      if(NULL == account) return false;
+      
+      QDomDocument document(file->fileName);
+      if(!readFile(fileName, document)) return false;
+      
+      return parseAccountDocument(document, *account);
+    }
+
+    project = parseStatisticsFileName(file->fileName);
+    if(!project.isNull())
+    {
+      KBSBOINCProjectStatistics *statistics = m_statistics.find(project);
+      if(NULL == statistics) return false;
+      
+      QDomDocument document(file->fileName);
+      if(!readFile(fileName, document)) return false;
+      
+      return parseStatisticsDocument(document, *statistics);
+    }
+
+    return false;
+  }
 }
 
-QString KBSBOINCMonitor::formatFileName(const QString &project)
+QString KBSBOINCMonitor::formatAccountFileName(const QString &project)
 {
-  return(BOINCAccountFilePrefix + project + BOINCAccountFileSuffix);
-  QString out(project);
-  
-  return out.prepend(BOINCAccountFilePrefix).append(BOINCAccountFileSuffix);
+  return(KBSBOINCAccountFilePrefix + project + KBSBOINCAccountFileSuffix);
 }
 
-QString KBSBOINCMonitor::parseFileName(const QString &fileName)
+QString KBSBOINCMonitor::formatStatisticsFileName(const QString &project)
 {
-  if(fileName.startsWith(BOINCAccountFilePrefix) && fileName.endsWith(BOINCAccountFileSuffix))
-    return fileName.mid(BOINCAccountFilePrefixLength,
-                        fileName.length() - BOINCAccountFilePrefixLength
-                                          - BOINCAccountFileSuffixLength); 
+  return(KBSBOINCStatisticsFilePrefix + project + KBSBOINCStatisticsFileSuffix);
+}
+
+QString KBSBOINCMonitor::parseAccountFileName(const QString &fileName)
+{
+  if(fileName.startsWith(KBSBOINCAccountFilePrefix)
+     && fileName.endsWith(KBSBOINCAccountFileSuffix))
+    return fileName.mid(KBSBOINCAccountFilePrefixLength,
+                        fileName.length() - KBSBOINCAccountFilePrefixLength
+                                          - KBSBOINCAccountFileSuffixLength); 
+  else
+    return QString::null;
+}
+
+QString KBSBOINCMonitor::parseStatisticsFileName(const QString &fileName)
+{
+  if(fileName.startsWith(KBSBOINCStatisticsFilePrefix)
+     && fileName.endsWith(KBSBOINCStatisticsFileSuffix))
+    return fileName.mid(KBSBOINCStatisticsFilePrefixLength,
+                        fileName.length() - KBSBOINCStatisticsFilePrefixLength
+                                          - KBSBOINCStatisticsFileSuffixLength); 
   else
     return QString::null;
 }
@@ -326,8 +424,8 @@ bool KBSBOINCMonitor::parseClientStateDocument(const QDomDocument &document)
   
   return true;
 }
-  
-bool KBSBOINCMonitor::parseAccountDocument(const QDomDocument &document, BOINCAccount &account)
+
+bool KBSBOINCMonitor::parseAccountDocument(const QDomDocument &document, KBSBOINCAccount &account)
 {
   QDomNode child = document.firstChild();
   while(!child.isNull()) {
@@ -347,6 +445,27 @@ bool KBSBOINCMonitor::parseAccountDocument(const QDomDocument &document, BOINCAc
   return true;
 }
 
+bool KBSBOINCMonitor::parseStatisticsDocument(const QDomDocument &document,
+                                              KBSBOINCProjectStatistics &statistics)
+{
+  QDomNode child = document.firstChild();
+  while(!child.isNull()) {
+    if(child.isElement()) {
+      QDomElement element = child.toElement();
+      
+      if(element.nodeName() == "project_statistics") {
+        if(!statistics.parse(element)) return false;
+      }
+    }
+    child = child.nextSibling();
+  }
+  
+  emit statisticsUpdated(project(statistics));
+  
+  qDebug("... parse OK");
+  return true;
+}
+
 bool KBSBOINCMonitor::validateResults()
 {
   QStringList workunits = m_state.workunit.keys();
@@ -375,29 +494,129 @@ void KBSBOINCMonitor::notify(const QString &message, const QString &text)
                        i18n("Host %1: %2").arg(m_location.host).arg(text));
 }
 
-void KBSBOINCMonitor::addAccounts(const QStringList &projects)
+KURL::List KBSBOINCMonitor::collectURLs(const KBSBOINCApp &app) const
+{
+  KURL::List out;
+
+  const QString name = app.name;
+  if(m_state.app_version.contains(name))
+    for(QValueList<KBSBOINCAppVersion>::const_iterator app_version = m_state.app_version[name].begin();
+        app_version != m_state.app_version[name].end(); ++app_version)
+      for(QValueList<KBSBOINCFileRef>::const_iterator file_ref = (*app_version).file_ref.begin();
+          file_ref != (*app_version).file_ref.end(); ++file_ref)
+        if(m_state.file_info.contains((*file_ref).file_name))
+          out += m_state.file_info[(*file_ref).file_name].url;
+  
+  return out;
+}
+
+KURL::List KBSBOINCMonitor::collectURLs(const KBSBOINCWorkunit &workunit, bool recursive) const
+{
+  KURL::List out;
+  
+  if(recursive)
+  {
+    if(!workunit.app_name.isEmpty() && m_state.app.contains(workunit.app_name))
+      out += collectURLs(m_state.app[workunit.app_name]);
+    
+    if(!workunit.result_name.isEmpty() && m_state.result.contains(workunit.result_name))
+      out += collectURLs(m_state.result[workunit.app_name], false);
+  }
+  
+  for(QValueList<KBSBOINCFileRef>::const_iterator file_ref = workunit.file_ref.begin();
+      file_ref != workunit.file_ref.end(); ++file_ref)
+    if(m_state.file_info.contains((*file_ref).file_name))
+      out += m_state.file_info[(*file_ref).file_name].url;
+  
+  return out;
+}
+
+KURL::List KBSBOINCMonitor::collectURLs(const KBSBOINCResult &result, bool recursive) const
+{
+  KURL::List out;
+  
+  if(recursive)
+    if(!result.wu_name.isEmpty() && m_state.workunit.contains(result.wu_name))
+      out += collectURLs(m_state.workunit[result.wu_name]);
+  
+  for(QValueList<KBSBOINCFileRef>::const_iterator file_ref = result.file_ref.begin();
+      file_ref != result.file_ref.end(); ++file_ref)
+    if(m_state.file_info.contains((*file_ref).file_name))
+      out += m_state.file_info[(*file_ref).file_name].url;
+  
+  return out;
+}
+
+double KBSBOINCMonitor::matchURL(const KURL &url, const KURL &scheduler_url)
+{
+  double result = 0.0;
+  QString host = url.host(),
+          scheduler_host = scheduler_url.host();
+  
+  if(host != scheduler_host)
+  {
+    unsigned const length = host.length(),
+                   scheduler_length = scheduler_host.length();
+    
+    unsigned i = length, j = scheduler_length;
+    
+    while(i > 0 && j > 0 && host.at(--i) == scheduler_host.at(--j))
+      ;
+    
+    result += (host.mid(i+1).contains('.')+1)/double(host.contains('.')+1);
+  }
+  else
+    result += 2.0;
+  
+  QString path = url.path(),
+          scheduler_path = scheduler_url.path();
+
+  if(path != scheduler_path)
+  {
+    unsigned const length = path.length(),
+                   scheduler_length = scheduler_path.length();
+    unsigned i = 0, j = 0;
+    
+    while(i < length && j < scheduler_length && path.at(i++) == scheduler_path.at(j++))
+      ;
+    
+    
+    result += 1e-3 * i/double(length);
+  }
+  else
+    result += 2e-3;
+  
+  return result;
+}
+
+void KBSBOINCMonitor::addProjectFiles(const QStringList &projects)
 {
   for(QStringList::const_iterator project = projects.constBegin();
       project != projects.constEnd(); ++project)
   {
-    m_accounts.insert(*project, new BOINCAccount());
+    m_accounts.insert(*project, new KBSBOINCAccount());
+    addFile(formatAccountFileName(*project));
     
-    const QString fileName = formatFileName(*project);
-    addFile(fileName);
-    setMonitoring(fileName, false);
+    m_statistics.insert(*project, new KBSBOINCProjectStatistics());
+    addFile(formatStatisticsFileName(*project));
   }
 }
 
-void KBSBOINCMonitor::removeAccounts(const QStringList &projects)
+void KBSBOINCMonitor::removeProjectFiles(const QStringList &projects)
 {
   for(QStringList::const_iterator project = projects.constBegin();
       project != projects.constEnd(); ++project)
   {
-    m_accounts.remove(*project);
-    removeFile(formatFileName(*project));
+    KBSBOINCAccount *account = m_accounts.take(*project);
+    if(NULL != account) delete account;
+    removeFile(formatAccountFileName(*project));
+    
+    KBSBOINCProjectStatistics *statistics = m_statistics.take(*project);
+    if(NULL != statistics) delete statistics;
+    removeFile(formatStatisticsFileName(*project));
   }
 }
-        
+
 void KBSBOINCMonitor::addProjectMonitors(const QStringList &projects)
 {
   KBSTreeNode *node = static_cast<KBSTreeNode*>(parent());
@@ -423,7 +642,12 @@ void KBSBOINCMonitor::removeProjectMonitors(const QStringList &projects)
 {
   for(QStringList::const_iterator project = projects.constBegin();
       project != projects.constEnd(); ++project)
-    m_projectMonitors.remove(*project);
+  {
+    KBSProjectMonitor *monitor = m_projectMonitors.take(*project);
+    if(NULL == monitor) continue;
+    
+    delete monitor;
+  }
 }
 
 void KBSBOINCMonitor::updateTaskMonitor(unsigned task, const QString &result, bool add)
@@ -445,26 +669,29 @@ void KBSBOINCMonitor::updateTaskMonitor(unsigned task, const QString &result, bo
     if(NULL == monitor) return;
     
     m_taskMonitors.insert(task, monitor);
-  } else
-    m_taskMonitors.remove(task);
+  }
+  else
+  {
+    KBSTaskMonitor *monitor = m_taskMonitors.take(task);
+    if(NULL != monitor) delete monitor;
+  }
 }
 
 void KBSBOINCMonitor::updateFile(const QString &fileName)
 {
   if(!(file(fileName)->ok)) return;
   
-  if(BOINCClientStateFile == fileName)
+  if(KBSBOINCClientStateFile == fileName)
   {
     {
-      const unsigned core_client_version =
-        m_state.core_client.major_version * 100 + m_state.core_client.minor_version;
-    
+      const unsigned version = m_state.core_client.major_version * 100 + m_state.core_client.minor_version;
+      
       if(0 == m_location.port)
-        m_rpcMonitor->setPort(core_client_version >= 420 ? 1043 : 31416);
+        m_rpcMonitor->setPort(version >= 420 && version < 503 ? 1043 : 31416);
     }
     {
       QStringList added, names, removed = m_projects;
-     
+      
       m_projects = m_state.project.keys();
       for(QStringList::iterator project = m_projects.begin();
           project != m_projects.end(); ++project)
@@ -499,7 +726,7 @@ void KBSBOINCMonitor::updateFile(const QString &fileName)
     }
     {
       QStringList added, removed = m_workunits;
-                  
+      
       m_workunits = m_state.workunit.keys();
       for(QStringList::iterator workunit = m_workunits.begin();
           workunit != m_workunits.end(); ++workunit)
@@ -556,12 +783,12 @@ void KBSBOINCMonitor::updateFile(const QString &fileName)
                  .arg(workunits.join(", "))); 
     }
     {
-      QMap<unsigned,BOINCActiveTask> removed = m_tasks;
+      QMap<unsigned,KBSBOINCActiveTask> removed = m_tasks;
       QValueList<unsigned> running;
       QStringList switched;
       
       m_tasks = m_state.active_task_set.active_task;
-      for(QMap<unsigned,BOINCActiveTask>::iterator task = m_tasks.begin();
+      for(QMap<unsigned,KBSBOINCActiveTask>::iterator task = m_tasks.begin();
           task != m_tasks.end(); ++task)
       {
         const QString newResult = (*task).result_name;
@@ -595,7 +822,7 @@ void KBSBOINCMonitor::updateFile(const QString &fileName)
           switched << QString::number(task.key());
         }
       }
-      for(QMap<unsigned,BOINCActiveTask>::iterator task = removed.begin();
+      for(QMap<unsigned,KBSBOINCActiveTask>::iterator task = removed.begin();
           task != removed.end(); ++task)
       {
         const QString oldResult = removed[task.key()].result_name;
@@ -622,10 +849,15 @@ void KBSBOINCMonitor::updateFile(const QString &fileName)
   }
   else
   {
-    QString project = parseFileName(fileName);
-    if(NULL == m_accounts.find(project)) return;
+    QString project;
     
-    emit accountUpdated(project);
+    project = parseAccountFileName(fileName);
+    if(!project.isEmpty() && NULL != m_accounts.find(project))
+      emit accountUpdated(project);
+    
+    project = parseStatisticsFileName(fileName);
+    if(!project.isEmpty() && NULL != m_statistics.find(project))
+      emit statisticsUpdated(project);
   }
 }
 
