@@ -1,19 +1,19 @@
 /***************************************************************************
  *   Copyright (C) 2005 by Roberto Virga                                   *
- *   rvirga@users.sf.net                                                   *
+ *   rvirga@users.sourceforge.net                                          *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
+ *   it under the terms of the GNU Library General Public License as       *
+ *   published by the Free Software Foundation; either version 2 of the    *
+ *   License, or (at your option) any later version.                       *
  *                                                                         *
  *   This program is distributed in the hope that it will be useful,       *
  *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
  *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
  *   GNU General Public License for more details.                          *
  *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program; if not, write to the                         *
+ *   You should have received a copy of the GNU Library General Public     *
+ *   License along with this program; if not, write to the                 *
  *   Free Software Foundation, Inc.,                                       *
  *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
  ***************************************************************************/
@@ -26,37 +26,35 @@
 
 #include "kbspredictorprojectmonitor.h"
 
-const QString PredictorBurialsOpenName = "burials";
-const QString PredictorECovers24OpenName = "ecovers_24";
-const QString PredictorProfile3OpenName = "profile3";
-const QString PredictorQuasi3OpenName = "quasi3";
-const QString PredictorScale3BOpenName = "scale3b";
-const QString PredictorS1234OpenName = "s1234";
-const QString PredictorS1234HOpenName = "s1234h";
-const QString PredictorS1234EOpenName = "s1234e";
-const QString PredictorMonssterInitChainOpenName = "monsster.init.chain";
-const QString PredictorMonssterInputOpenName = "monsster.input";
-const QString PredictorMonssterSeqOpenName = "monsster.seq";
-const QString PredictorMonssterRestraintsOpenName = "monsster.restraints";
-const QString PredictorMonssterFinalChainOpenName = "monsster.final.chain";
-const QString PredictorMonssterFinalPDBOpenName = "monsster.final.pdb";
-const QString PredictorMonssterFinalNOEOpenName = "monsster.final.noe";
+const QString KBSPredictorBurialsOpenName = "burials";
+const QString KBSPredictorECovers24OpenName = "ecovers_24";
+const QString KBSPredictorProfile3OpenName = "profile3";
+const QString KBSPredictorQuasi3OpenName = "quasi3";
+const QString KBSPredictorScale3BOpenName = "scale3b";
+const QString KBSPredictorS1234OpenName = "s1234";
+const QString KBSPredictorS1234HOpenName = "s1234h";
+const QString KBSPredictorS1234EOpenName = "s1234e";
+const QString KBSPredictorMonssterInitChainOpenName = "monsster.init.chain";
+const QString KBSPredictorMonssterInputOpenName = "monsster.input";
+const QString KBSPredictorMonssterSeqOpenName = "monsster.seq";
+const QString KBSPredictorMonssterRestraintsOpenName = "monsster.restraints";
+const QString KBSPredictorMonssterFinalChainOpenName = "monsster.final.chain";
+const QString KBSPredictorMonssterFinalPDBOpenName = "monsster.final.pdb";
+const QString KBSPredictorMonssterFinalNOEOpenName = "monsster.final.noe";
 
-const QString PredictorParam19InpOpenName = "param19.inp";
-const QString PredictorTopH19InpOpenName = "toph19.inp";
-const QString PredictorCharmmInpOpenName = "charmm.inp";
-const QString PredictorProteinPDBOpenName = "protein.pdb";
-const QString PredictorProteinNOEOpenName = "protein.noe";
-const QString PredictorSeedStreamOpenName = "seed.stream";
-const QString PredictorProteinFinalPDBOpenName = "proteinfinal.pdb";
+const QString KBSPredictorParam19InpOpenName = "param19.inp";
+const QString KBSPredictorTopH19InpOpenName = "toph19.inp";
+const QString KBSPredictorCharmmInpOpenName = "charmm.inp";
+const QString KBSPredictorProteinPDBOpenName = "protein.pdb";
+const QString KBSPredictorProteinNOEOpenName = "protein.noe";
+const QString KBSPredictorSeedStreamOpenName = "seed.stream";
+const QString KBSPredictorProteinFinalPDBOpenName = "proteinfinal.pdb";
 
 KBSPredictorProjectMonitor::KBSPredictorProjectMonitor(const QString &project, KBSBOINCMonitor *parent,
                                                        const char *name)
                           : KBSProjectMonitor(project, parent, name)
 {
-  m_results.setAutoDelete(true);
-  
-  const BOINCClientState *state = parent->state();
+  const KBSBOINCClientState *state = parent->state();
   if(NULL != state) m_start = state->workunit.keys();
   
   connect(parent, SIGNAL(workunitsRemoved(const QStringList &)),
@@ -68,18 +66,24 @@ KBSPredictorProjectMonitor::KBSPredictorProjectMonitor(const QString &project, K
   connect(this, SIGNAL(fileUpdated(const QString &)), this, SLOT(updateFile(const QString &)));
 }
 
-const PredictorResult *KBSPredictorProjectMonitor::result(const QString &workunit)
+KBSPredictorProjectMonitor::~KBSPredictorProjectMonitor()
+{
+  for(QDictIterator<KBSPredictorResult> it(m_results); it.current() != NULL; ++it)
+    delete it.current();
+  m_results.clear();
+}
+
+const KBSPredictorResult *KBSPredictorProjectMonitor::result(const QString &workunit)
 {
   return validWorkunit(workunit) ? m_results.find(workunit) : NULL;
 }
 
-void KBSPredictorProjectMonitor::setState(const QString &workunit, const PredictorState &state)
+void KBSPredictorProjectMonitor::setState(const QString &workunit, const KBSPredictorState &state)
 {
-  PredictorResult *result = m_results.find(workunit);
+  KBSPredictorResult *result = mkResult(workunit);
   if(NULL == result) {
-    result = new PredictorResult();
+    result = mkResult(workunit);
     result->app_type = state.app_type;
-    m_results.insert(workunit, result);
   }
   
   if(result->app_type != state.app_type) return;
@@ -97,26 +101,26 @@ KBSLogManager *KBSPredictorProjectMonitor::logManager() const
     
 bool KBSPredictorProjectMonitor::parseable(const QString &openName) const
 {
-  return(// openName == PredictorBurialsOpenName
-   // || openName == PredictorECovers24OpenName
-   // || openName == PredictorProfile3OpenName
-   // || openName == PredictorQuasi3OpenName
-   // || openName == PredictorScale3BOpenName
-   // || openName == PredictorS1234OpenName
-   // || openName == PredictorS1234HOpenName
-   // || openName == PredictorS1234EOpenName
-         openName == PredictorMonssterInitChainOpenName
-      || openName == PredictorMonssterInputOpenName
-      || openName == PredictorMonssterSeqOpenName
-      || openName == PredictorMonssterRestraintsOpenName
-      || openName == PredictorMonssterFinalChainOpenName
-      || openName == PredictorMonssterFinalPDBOpenName
-   // || openName == PredictorMonssterFinalNOEOpenName
-      || openName == PredictorCharmmInpOpenName
-      || openName == PredictorProteinPDBOpenName
-      || openName == PredictorProteinNOEOpenName
-      || openName == PredictorSeedStreamOpenName
-      || openName == PredictorProteinFinalPDBOpenName);
+  return(// openName == KBSPredictorBurialsOpenName
+   // || openName == KBSPredictorECovers24OpenName
+   // || openName == KBSPredictorProfile3OpenName
+   // || openName == KBSPredictorQuasi3OpenName
+   // || openName == KBSPredictorScale3BOpenName
+   // || openName == KBSPredictorS1234OpenName
+   // || openName == KBSPredictorS1234HOpenName
+   // || openName == KBSPredictorS1234EOpenName
+         openName == KBSPredictorMonssterInitChainOpenName
+      || openName == KBSPredictorMonssterInputOpenName
+      || openName == KBSPredictorMonssterSeqOpenName
+      || openName == KBSPredictorMonssterRestraintsOpenName
+      || openName == KBSPredictorMonssterFinalChainOpenName
+      || openName == KBSPredictorMonssterFinalPDBOpenName
+   // || openName == KBSPredictorMonssterFinalNOEOpenName
+      || openName == KBSPredictorCharmmInpOpenName
+      || openName == KBSPredictorProteinPDBOpenName
+      || openName == KBSPredictorProteinNOEOpenName
+      || openName == KBSPredictorSeedStreamOpenName
+      || openName == KBSPredictorProteinFinalPDBOpenName);
 }
 
 bool KBSPredictorProjectMonitor::parseFile(KBSFileInfo *file, const QString &fileName)
@@ -129,9 +133,9 @@ bool KBSPredictorProjectMonitor::parseFile(KBSFileInfo *file, const QString &fil
   if(!m_meta.contains(file->fileName)) return false;
   const KBSFileMetaInfo meta = m_meta[file->fileName];
   
-  if(PredictorBurialsOpenName == meta.open_name)
+  if(KBSPredictorBurialsOpenName == meta.open_name)
   {
-    PredictorBurials burials;
+    KBSPredictorBurials burials;
     if(!burials.parse(lines)) return false;
     
     setBurials(burials, meta.workunits);
@@ -139,9 +143,9 @@ bool KBSPredictorProjectMonitor::parseFile(KBSFileInfo *file, const QString &fil
     qDebug("... parse OK");
     return true;
   }
-  else if(PredictorECovers24OpenName == meta.open_name)
+  else if(KBSPredictorECovers24OpenName == meta.open_name)
   {
-    PredictorECovers24 ecovers_24;
+    KBSPredictorECovers24 ecovers_24;
     if(!ecovers_24.parse(lines)) return false;
     
     setECovers24(ecovers_24, meta.workunits);
@@ -149,9 +153,9 @@ bool KBSPredictorProjectMonitor::parseFile(KBSFileInfo *file, const QString &fil
     qDebug("... parse OK");
     return true;
   }
-  else if(PredictorProfile3OpenName == meta.open_name)
+  else if(KBSPredictorProfile3OpenName == meta.open_name)
   {
-    PredictorProfile3 profile3;
+    KBSPredictorProfile3 profile3;
     if(!profile3.parse(lines)) return false;
     
     setProfile3(profile3, meta.workunits);
@@ -159,9 +163,9 @@ bool KBSPredictorProjectMonitor::parseFile(KBSFileInfo *file, const QString &fil
     qDebug("... parse OK");
     return true;
   }
-  else if(PredictorQuasi3OpenName == meta.open_name)
+  else if(KBSPredictorQuasi3OpenName == meta.open_name)
   {
-    PredictorQuasi3 quasi3;
+    KBSPredictorQuasi3 quasi3;
     if(!quasi3.parse(lines)) return false;
     
     setQuasi3(quasi3, meta.workunits);
@@ -169,9 +173,9 @@ bool KBSPredictorProjectMonitor::parseFile(KBSFileInfo *file, const QString &fil
     qDebug("... parse OK");
     return true;
   }
-  else if(PredictorScale3BOpenName == meta.open_name)
+  else if(KBSPredictorScale3BOpenName == meta.open_name)
   {
-    QValueList<PredictorScale3B> scale3b;
+    QValueList<KBSPredictorScale3B> scale3b;
     if(!parseScale3B(lines, scale3b)) return false;
     
     setScale3B(scale3b, meta.workunits);
@@ -179,9 +183,9 @@ bool KBSPredictorProjectMonitor::parseFile(KBSFileInfo *file, const QString &fil
     qDebug("... parse OK");
     return true;
   }
-  else if(PredictorS1234OpenName == meta.open_name)
+  else if(KBSPredictorS1234OpenName == meta.open_name)
   {
-    PredictorS1234 s1234;
+    KBSPredictorS1234 s1234;
     if(!s1234.parse(lines)) return false;
     
     setS1234(s1234, meta.workunits);
@@ -189,9 +193,9 @@ bool KBSPredictorProjectMonitor::parseFile(KBSFileInfo *file, const QString &fil
     qDebug("... parse OK");
     return true;
   }
-  else if(PredictorS1234HOpenName == meta.open_name)
+  else if(KBSPredictorS1234HOpenName == meta.open_name)
   {
-    PredictorS1234 s1234h;
+    KBSPredictorS1234 s1234h;
     if(!s1234h.parse(lines)) return false;
     
     setS1234H(s1234h, meta.workunits);
@@ -199,9 +203,9 @@ bool KBSPredictorProjectMonitor::parseFile(KBSFileInfo *file, const QString &fil
     qDebug("... parse OK");
     return true;
   }
-  else if(PredictorS1234EOpenName == meta.open_name)
+  else if(KBSPredictorS1234EOpenName == meta.open_name)
   {
-    PredictorS1234 s1234e;
+    KBSPredictorS1234 s1234e;
     if(!s1234e.parse(lines)) return false;
     
     setS1234E(s1234e, meta.workunits);
@@ -209,9 +213,9 @@ bool KBSPredictorProjectMonitor::parseFile(KBSFileInfo *file, const QString &fil
     qDebug("... parse OK");
     return true;
   }
-  else if(PredictorMonssterInitChainOpenName == meta.open_name)
+  else if(KBSPredictorMonssterInitChainOpenName == meta.open_name)
   {
-    QValueList<PredictorMonssterAtom> init_chain;
+    QValueList<KBSPredictorMonssterAtom> init_chain;
     if(!parseMonssterChain(lines, init_chain)) return false;
     
     setMonssterInitChain(init_chain, meta.workunits);
@@ -219,9 +223,9 @@ bool KBSPredictorProjectMonitor::parseFile(KBSFileInfo *file, const QString &fil
     qDebug("... parse OK");
     return true;
   }
-  else if(PredictorMonssterInputOpenName == meta.open_name)
+  else if(KBSPredictorMonssterInputOpenName == meta.open_name)
   {
-    PredictorMonssterInput input;
+    KBSPredictorMonssterInput input;
     if(!input.parse(lines)) return false;
     
     setMonssterInput(input, meta.workunits);
@@ -229,9 +233,9 @@ bool KBSPredictorProjectMonitor::parseFile(KBSFileInfo *file, const QString &fil
     qDebug("... parse OK");
     return true;
   }
-  else if(PredictorMonssterSeqOpenName == meta.open_name)
+  else if(KBSPredictorMonssterSeqOpenName == meta.open_name)
   {
-    PredictorMonssterSeq seq;
+    KBSPredictorMonssterSeq seq;
     if(!seq.parse(lines)) return false;
     
     setMonssterSeq(seq, meta.workunits);
@@ -239,9 +243,9 @@ bool KBSPredictorProjectMonitor::parseFile(KBSFileInfo *file, const QString &fil
     qDebug("... parse OK");
     return true;
   }
-  else if(PredictorMonssterRestraintsOpenName == meta.open_name)
+  else if(KBSPredictorMonssterRestraintsOpenName == meta.open_name)
   {
-    QValueList<PredictorMonssterRestraint> restraints;
+    QValueList<KBSPredictorMonssterRestraint> restraints;
     if(!parseMonssterRestraints(lines, restraints)) return false;
     
     setMonssterRestraints(restraints, meta.workunits);
@@ -249,9 +253,9 @@ bool KBSPredictorProjectMonitor::parseFile(KBSFileInfo *file, const QString &fil
     qDebug("... parse OK");
     return true;
   }
-  else if(PredictorMonssterFinalChainOpenName == meta.open_name)
+  else if(KBSPredictorMonssterFinalChainOpenName == meta.open_name)
   {
-    QValueList<PredictorMonssterAtom> final_chain;
+    QValueList<KBSPredictorMonssterAtom> final_chain;
     if(!parseMonssterChain(lines, final_chain)) return false;
     
     setMonssterFinalChain(final_chain, meta.workunits);
@@ -259,9 +263,9 @@ bool KBSPredictorProjectMonitor::parseFile(KBSFileInfo *file, const QString &fil
     qDebug("... parse OK");
     return true;
   }
-  else if(PredictorMonssterFinalPDBOpenName == meta.open_name)
+  else if(KBSPredictorMonssterFinalPDBOpenName == meta.open_name)
   {
-    PredictorProteinPDB final_pdb;
+    KBSPredictorProteinPDB final_pdb;
     if(!final_pdb.parse(lines)) return false;
     
     setMonssterFinalPDB(final_pdb, meta.workunits);
@@ -269,9 +273,9 @@ bool KBSPredictorProjectMonitor::parseFile(KBSFileInfo *file, const QString &fil
     qDebug("... parse OK");
     return true;
   }
-  else if(PredictorMonssterFinalNOEOpenName == meta.open_name)
+  else if(KBSPredictorMonssterFinalNOEOpenName == meta.open_name)
   {
-    QValueList<PredictorProteinNOE> final_noe;
+    QValueList<KBSPredictorProteinNOE> final_noe;
     if(!parseProteinNOE(lines, final_noe)) return false;
     
     setMonssterFinalNOE(final_noe, meta.workunits);
@@ -279,23 +283,23 @@ bool KBSPredictorProjectMonitor::parseFile(KBSFileInfo *file, const QString &fil
     qDebug("... parse OK");
     return true;
   }
-  else if(PredictorParam19InpOpenName == meta.open_name)
+  else if(KBSPredictorParam19InpOpenName == meta.open_name)
   {
     setAppType(CHARMM, meta.workunits);
     
     qDebug("... parse OK");
     return true;
   }
-  else if(PredictorTopH19InpOpenName == meta.open_name)
+  else if(KBSPredictorTopH19InpOpenName == meta.open_name)
   {
     setAppType(CHARMM, meta.workunits);
     
     qDebug("... parse OK");
     return true;
   }
-  else if(PredictorCharmmInpOpenName == meta.open_name)
+  else if(KBSPredictorCharmmInpOpenName == meta.open_name)
   {
-    PredictorCharmmInp inp;
+    KBSPredictorCharmmInp inp;
     if(!inp.parse(lines)) return false;
     
     setCharmmInp(inp, meta.workunits);
@@ -303,9 +307,9 @@ bool KBSPredictorProjectMonitor::parseFile(KBSFileInfo *file, const QString &fil
     qDebug("... parse OK");
     return true;
   }
-  else if(PredictorProteinPDBOpenName == meta.open_name)
+  else if(KBSPredictorProteinPDBOpenName == meta.open_name)
   {
-    PredictorProteinPDB pdb;
+    KBSPredictorProteinPDB pdb;
     if(!pdb.parse(lines)) return false;
     
     setProteinPDB(pdb, meta.workunits);
@@ -313,9 +317,9 @@ bool KBSPredictorProjectMonitor::parseFile(KBSFileInfo *file, const QString &fil
     qDebug("... parse OK");
     return true;
   }
-  else if(PredictorProteinNOEOpenName == meta.open_name)
+  else if(KBSPredictorProteinNOEOpenName == meta.open_name)
   {
-    QValueList<PredictorProteinNOE> noe;
+    QValueList<KBSPredictorProteinNOE> noe;
     if(!parseProteinNOE(lines, noe)) return false;
     
     setProteinNOE(noe, meta.workunits);
@@ -323,7 +327,7 @@ bool KBSPredictorProjectMonitor::parseFile(KBSFileInfo *file, const QString &fil
     qDebug("... parse OK");
     return true;
   }
-  else if(PredictorSeedStreamOpenName == meta.open_name)
+  else if(KBSPredictorSeedStreamOpenName == meta.open_name)
   {
     unsigned seed;
     if(!parseSeedStream(lines, seed)) return false;
@@ -333,9 +337,9 @@ bool KBSPredictorProjectMonitor::parseFile(KBSFileInfo *file, const QString &fil
     qDebug("... parse OK");
     return true;
   }
-  else if(PredictorProteinFinalPDBOpenName == meta.open_name)
+  else if(KBSPredictorProteinFinalPDBOpenName == meta.open_name)
   {
-    PredictorProteinPDB final_pdb;
+    KBSPredictorProteinPDB final_pdb;
     if(!final_pdb.parse(lines)) return false;
     
     setProteinFinalPDB(final_pdb, meta.workunits);
@@ -347,12 +351,12 @@ bool KBSPredictorProjectMonitor::parseFile(KBSFileInfo *file, const QString &fil
     return false;
 }
 
-PredictorResult *KBSPredictorProjectMonitor::mkResult(const QString &workunit)
+KBSPredictorResult *KBSPredictorProjectMonitor::mkResult(const QString &workunit)
 {
-  PredictorResult *result = m_results.find(workunit);
+  KBSPredictorResult *result = m_results.find(workunit);
   
   if(NULL == result) {
-    result = new PredictorResult();
+    result = new KBSPredictorResult();
     m_results.insert(workunit, result);
   }
   
@@ -360,7 +364,7 @@ PredictorResult *KBSPredictorProjectMonitor::mkResult(const QString &workunit)
 }
 
 bool KBSPredictorProjectMonitor::parseScale3B(const QStringList &lines,
-                                              QValueList<PredictorScale3B> &scale3b)
+                                              QValueList<KBSPredictorScale3B> &scale3b)
 {
   scale3b.clear();
   QStringList::const_iterator line = lines.constBegin();
@@ -373,7 +377,7 @@ bool KBSPredictorProjectMonitor::parseScale3B(const QStringList &lines,
   {
     if(lines.constEnd() == line) return false;
     
-    PredictorScale3B item;
+    KBSPredictorScale3B item;
     if(!item.parse(*line)) return false;
 
     scale3b << item;
@@ -384,7 +388,7 @@ bool KBSPredictorProjectMonitor::parseScale3B(const QStringList &lines,
 }
 
 bool KBSPredictorProjectMonitor::parseMonssterChain(const QStringList &lines,
-                                                    QValueList<PredictorMonssterAtom> &chain)
+                                                    QValueList<KBSPredictorMonssterAtom> &chain)
 {
   chain.clear();
 
@@ -399,7 +403,7 @@ bool KBSPredictorProjectMonitor::parseMonssterChain(const QStringList &lines,
   
   for(unsigned i = 0; i < n; i++)
   {
-    PredictorMonssterAtom item;
+    KBSPredictorMonssterAtom item;
     
     if(lines.constEnd() == line || !item.parse(*line)) return false;
     ++line;
@@ -411,7 +415,7 @@ bool KBSPredictorProjectMonitor::parseMonssterChain(const QStringList &lines,
 }
 
 bool KBSPredictorProjectMonitor::parseMonssterRestraints(const QStringList &lines,
-                                                         QValueList<PredictorMonssterRestraint> &restraints)
+                                                         QValueList<KBSPredictorMonssterRestraint> &restraints)
 {
   restraints.clear();
   QStringList::const_iterator line = lines.constBegin();
@@ -424,7 +428,7 @@ bool KBSPredictorProjectMonitor::parseMonssterRestraints(const QStringList &line
   {
     if(lines.constEnd() == line) return false;
     
-    PredictorMonssterRestraint item;
+    KBSPredictorMonssterRestraint item;
     if(!item.parse(*line)) return false;
     
     restraints << item;
@@ -435,7 +439,7 @@ bool KBSPredictorProjectMonitor::parseMonssterRestraints(const QStringList &line
 }
 
 bool KBSPredictorProjectMonitor::parseProteinNOE(const QStringList &lines,
-                                                 QValueList<PredictorProteinNOE> &noe)
+                                                 QValueList<KBSPredictorProteinNOE> &noe)
 {
   noe.clear();
   QStringList::const_iterator line = lines.constBegin();
@@ -448,7 +452,7 @@ bool KBSPredictorProjectMonitor::parseProteinNOE(const QStringList &lines,
   {
     if((*line).startsWith("END")) break;
     
-    PredictorProteinNOE item;
+    KBSPredictorProteinNOE item;
     if(!item.parse(*line)) return false;
     
     noe << item;
@@ -468,119 +472,119 @@ bool KBSPredictorProjectMonitor::parseSeedStream(const QStringList &lines, unsig
   return true;
 }
 
-void KBSPredictorProjectMonitor::setAppType(PredictorAppType app_type, const QStringList &workunits)
+void KBSPredictorProjectMonitor::setAppType(KBSPredictorAppType app_type, const QStringList &workunits)
 {
   for(QStringList::const_iterator workunit = workunits.begin();
       workunit != workunits.end(); ++ workunit)
     mkResult(*workunit)->app_type = app_type;
 }
 
-void KBSPredictorProjectMonitor::setBurials(const PredictorBurials &burials, const QStringList &workunits)
+void KBSPredictorProjectMonitor::setBurials(const KBSPredictorBurials &burials, const QStringList &workunits)
 {
   for(QStringList::const_iterator workunit = workunits.begin();
       workunit != workunits.end(); ++ workunit)
   {
-    PredictorResult *result = mkResult(*workunit);
+    KBSPredictorResult *result = mkResult(*workunit);
     
     result->app_type = MFOLD;
     result->mfold.burials = burials;
   }
 }
 
-void KBSPredictorProjectMonitor::setECovers24(const PredictorECovers24 &ecovers_24,
+void KBSPredictorProjectMonitor::setECovers24(const KBSPredictorECovers24 &ecovers_24,
                                               const QStringList &workunits)
 {
   for(QStringList::const_iterator workunit = workunits.begin();
       workunit != workunits.end(); ++ workunit)
   {
-    PredictorResult *result = mkResult(*workunit);
+    KBSPredictorResult *result = mkResult(*workunit);
     
     result->app_type = MFOLD;
     result->mfold.ecovers_24 = ecovers_24;
   }
 }
 
-void KBSPredictorProjectMonitor::setProfile3(const PredictorProfile3 &profile3,
+void KBSPredictorProjectMonitor::setProfile3(const KBSPredictorProfile3 &profile3,
                                              const QStringList &workunits)
 {
   for(QStringList::const_iterator workunit = workunits.begin();
       workunit != workunits.end(); ++ workunit)
   {
-    PredictorResult *result = mkResult(*workunit);
+    KBSPredictorResult *result = mkResult(*workunit);
     
     result->app_type = MFOLD;
     result->mfold.profile3 = profile3;
   }
 }
 
-void KBSPredictorProjectMonitor::setQuasi3(const PredictorQuasi3 &quasi3, const QStringList &workunits)
+void KBSPredictorProjectMonitor::setQuasi3(const KBSPredictorQuasi3 &quasi3, const QStringList &workunits)
 {
   for(QStringList::const_iterator workunit = workunits.begin();
       workunit != workunits.end(); ++ workunit)
   {
-    PredictorResult *result = mkResult(*workunit);
+    KBSPredictorResult *result = mkResult(*workunit);
     
     result->app_type = MFOLD;
     result->mfold.quasi3 = quasi3;
   }
 }
 
-void KBSPredictorProjectMonitor::setScale3B(const QValueList<PredictorScale3B> &scale3b,
+void KBSPredictorProjectMonitor::setScale3B(const QValueList<KBSPredictorScale3B> &scale3b,
                                             const QStringList &workunits)
 {
   for(QStringList::const_iterator workunit = workunits.begin();
       workunit != workunits.end(); ++ workunit)
   {
-    PredictorResult *result = mkResult(*workunit);
+    KBSPredictorResult *result = mkResult(*workunit);
     
     result->app_type = MFOLD;
     result->mfold.scale3b = scale3b;
   }
 }
 
-void KBSPredictorProjectMonitor::setS1234(const PredictorS1234 &s1234, const QStringList &workunits)
+void KBSPredictorProjectMonitor::setS1234(const KBSPredictorS1234 &s1234, const QStringList &workunits)
 {
   for(QStringList::const_iterator workunit = workunits.begin();
       workunit != workunits.end(); ++ workunit)
   {
-    PredictorResult *result = mkResult(*workunit);
+    KBSPredictorResult *result = mkResult(*workunit);
     
     result->app_type = MFOLD;
     result->mfold.s1234 = s1234;
   }
 }
 
-void KBSPredictorProjectMonitor::setS1234H(const PredictorS1234 &s1234h, const QStringList &workunits)
+void KBSPredictorProjectMonitor::setS1234H(const KBSPredictorS1234 &s1234h, const QStringList &workunits)
 {
   for(QStringList::const_iterator workunit = workunits.begin();
       workunit != workunits.end(); ++ workunit)
   {
-    PredictorResult *result = mkResult(*workunit);
+    KBSPredictorResult *result = mkResult(*workunit);
     
     result->app_type = MFOLD;
     result->mfold.s1234h = s1234h;
   }
 }
 
-void KBSPredictorProjectMonitor::setS1234E(const PredictorS1234 &s1234e, const QStringList &workunits)
+void KBSPredictorProjectMonitor::setS1234E(const KBSPredictorS1234 &s1234e, const QStringList &workunits)
 {
   for(QStringList::const_iterator workunit = workunits.begin();
       workunit != workunits.end(); ++ workunit)
   {
-    PredictorResult *result = mkResult(*workunit);
+    KBSPredictorResult *result = mkResult(*workunit);
     
     result->app_type = MFOLD;
     result->mfold.s1234e = s1234e;
   }
 }
 
-void KBSPredictorProjectMonitor::setMonssterInitChain(const QValueList<PredictorMonssterAtom> &init_chain,
+void KBSPredictorProjectMonitor::setMonssterInitChain(const QValueList<KBSPredictorMonssterAtom> &init_chain,
                                                       const QStringList &workunits)
 {
   for(QStringList::const_iterator workunit = workunits.begin();
       workunit != workunits.end(); ++ workunit)
   {
-    PredictorResult *result = mkResult(*workunit);
+    KBSPredictorResult *result = mkResult(*workunit);
     
     result->app_type = MFOLD;
     result->mfold.monsster.init_chain = init_chain;
@@ -590,26 +594,26 @@ void KBSPredictorProjectMonitor::setMonssterInitChain(const QValueList<Predictor
   }
 }
 
-void KBSPredictorProjectMonitor::setMonssterInput(const PredictorMonssterInput &input,
+void KBSPredictorProjectMonitor::setMonssterInput(const KBSPredictorMonssterInput &input,
                                                   const QStringList &workunits)
 {
   for(QStringList::const_iterator workunit = workunits.begin();
       workunit != workunits.end(); ++ workunit)
   {
-    PredictorResult *result = mkResult(*workunit);
+    KBSPredictorResult *result = mkResult(*workunit);
     
     result->app_type = MFOLD;
     result->mfold.monsster.input = input;
   }
 }
 
-void KBSPredictorProjectMonitor::setMonssterSeq(const PredictorMonssterSeq &seq,
+void KBSPredictorProjectMonitor::setMonssterSeq(const KBSPredictorMonssterSeq &seq,
                                                 const QStringList &workunits)
 {
   for(QStringList::const_iterator workunit = workunits.begin();
       workunit != workunits.end(); ++ workunit)
   {
-    PredictorResult *result = mkResult(*workunit);
+    KBSPredictorResult *result = mkResult(*workunit);
     
     result->app_type = MFOLD;
     result->mfold.monsster.seq = seq;
@@ -619,65 +623,65 @@ void KBSPredictorProjectMonitor::setMonssterSeq(const PredictorMonssterSeq &seq,
   }
 }
 
-void KBSPredictorProjectMonitor::setMonssterRestraints(const QValueList<PredictorMonssterRestraint> &restraints,
+void KBSPredictorProjectMonitor::setMonssterRestraints(const QValueList<KBSPredictorMonssterRestraint> &restraints,
                                                        const QStringList &workunits)
 {
   for(QStringList::const_iterator workunit = workunits.begin();
       workunit != workunits.end(); ++ workunit)
   {
-    PredictorResult *result = mkResult(*workunit);
+    KBSPredictorResult *result = mkResult(*workunit);
     
     result->app_type = MFOLD;
     result->mfold.monsster.restraints = restraints;
   }
 }
 
-void KBSPredictorProjectMonitor::setMonssterFinalChain(const QValueList<PredictorMonssterAtom> &final_chain,
+void KBSPredictorProjectMonitor::setMonssterFinalChain(const QValueList<KBSPredictorMonssterAtom> &final_chain,
                                                        const QStringList &workunits)
 {
   for(QStringList::const_iterator workunit = workunits.begin();
       workunit != workunits.end(); ++ workunit)
   {
-    PredictorResult *result = mkResult(*workunit);
+    KBSPredictorResult *result = mkResult(*workunit);
     
     result->app_type = MFOLD;
     result->mfold.monsster.final.chain = final_chain;
   }
 }
 
-void KBSPredictorProjectMonitor::setMonssterFinalPDB(const PredictorProteinPDB &final_pdb,
+void KBSPredictorProjectMonitor::setMonssterFinalPDB(const KBSPredictorProteinPDB &final_pdb,
                                                        const QStringList &workunits)
 {
   for(QStringList::const_iterator workunit = workunits.begin();
       workunit != workunits.end(); ++ workunit)
   {
-    PredictorResult *result = mkResult(*workunit);
+    KBSPredictorResult *result = mkResult(*workunit);
     
     result->app_type = MFOLD;
     result->mfold.monsster.final.pdb = final_pdb;
   }
 }
 
-void KBSPredictorProjectMonitor::setMonssterFinalNOE(const QValueList<PredictorProteinNOE> &final_noe,
+void KBSPredictorProjectMonitor::setMonssterFinalNOE(const QValueList<KBSPredictorProteinNOE> &final_noe,
                                                        const QStringList &workunits)
 {
   for(QStringList::const_iterator workunit = workunits.begin();
       workunit != workunits.end(); ++ workunit)
   {
-    PredictorResult *result = mkResult(*workunit);
+    KBSPredictorResult *result = mkResult(*workunit);
     
     result->app_type = MFOLD;
     result->mfold.monsster.final.noe = final_noe;
   }
 }
 
-void KBSPredictorProjectMonitor::setCharmmInp(const PredictorCharmmInp &inp,
+void KBSPredictorProjectMonitor::setCharmmInp(const KBSPredictorCharmmInp &inp,
                                               const QStringList &workunits)
 {
   for(QStringList::const_iterator workunit = workunits.begin();
       workunit != workunits.end(); ++ workunit)
   {
-    PredictorResult *result = mkResult(*workunit);
+    KBSPredictorResult *result = mkResult(*workunit);
     
     result->app_type = CHARMM;
     result->charmm.inp = inp;
@@ -687,13 +691,13 @@ void KBSPredictorProjectMonitor::setCharmmInp(const PredictorCharmmInp &inp,
   }
 }
 
-void KBSPredictorProjectMonitor::setProteinPDB(const PredictorProteinPDB &pdb,
+void KBSPredictorProjectMonitor::setProteinPDB(const KBSPredictorProteinPDB &pdb,
                                                const QStringList &workunits)
 {
   for(QStringList::const_iterator workunit = workunits.begin();
       workunit != workunits.end(); ++ workunit)
   {
-    PredictorResult *result = mkResult(*workunit);
+    KBSPredictorResult *result = mkResult(*workunit);
     
     result->app_type = CHARMM;
     result->charmm.protein.pdb = pdb;
@@ -703,13 +707,13 @@ void KBSPredictorProjectMonitor::setProteinPDB(const PredictorProteinPDB &pdb,
   }
 }
 
-void KBSPredictorProjectMonitor::setProteinNOE(const QValueList<PredictorProteinNOE> &noe,
+void KBSPredictorProjectMonitor::setProteinNOE(const QValueList<KBSPredictorProteinNOE> &noe,
                                                const QStringList &workunits)
 {
   for(QStringList::const_iterator workunit = workunits.begin();
       workunit != workunits.end(); ++ workunit)
   {
-    PredictorResult *result = mkResult(*workunit);
+    KBSPredictorResult *result = mkResult(*workunit);
     
     result->app_type = CHARMM;
     result->charmm.protein.noe = noe;
@@ -721,20 +725,20 @@ void KBSPredictorProjectMonitor::setSeedStream(unsigned seed, const QStringList
   for(QStringList::const_iterator workunit = workunits.begin();
       workunit != workunits.end(); ++ workunit)
   {
-    PredictorResult *result = mkResult(*workunit);
+    KBSPredictorResult *result = mkResult(*workunit);
     
     result->app_type = CHARMM;
     result->charmm.seed.stream = seed;
   }
 }
 
-void KBSPredictorProjectMonitor::setProteinFinalPDB(const PredictorProteinPDB &final_pdb,
+void KBSPredictorProjectMonitor::setProteinFinalPDB(const KBSPredictorProteinPDB &final_pdb,
                                                     const QStringList &workunits)
 {
   for(QStringList::const_iterator workunit = workunits.begin();
       workunit != workunits.end(); ++ workunit)
   {
-    PredictorResult *result = mkResult(*workunit);
+    KBSPredictorResult *result = mkResult(*workunit);
     
     result->app_type = CHARMM;
     result->charmm.protein.final_pdb = final_pdb;
@@ -745,19 +749,22 @@ void KBSPredictorProjectMonitor::removeWorkunits(const QStringList &workunits)
 {
   for(QStringList::const_iterator workunit = workunits.constBegin();
       workunit != workunits.constEnd(); ++workunit)
-    m_results.remove(*workunit);
+  {
+    KBSPredictorResult *result = m_results.take(*workunit);
+    if(NULL != result) delete result;
+  }
 }
 
 void KBSPredictorProjectMonitor::logResults(const QStringList &results)
 {
-  const BOINCClientState *state = boincMonitor()->state();
+  const KBSBOINCClientState *state = boincMonitor()->state();
   if(NULL == state) return;
   
   for(QStringList::const_iterator result = results.constBegin(); result != results.constEnd(); ++result)
   {
     if(boincMonitor()->project(state->result[*result]) != project()) continue;
     
-    PredictorResult *predictorResult = m_results.find(state->result[*result].wu_name);
+    KBSPredictorResult *predictorResult = m_results.find(state->result[*result].wu_name);
     if(NULL == predictorResult) continue;
     
     KBSPredictorMoleculeLog::self()->logResult(*result, predictorResult);
