@@ -1,19 +1,19 @@
 /***************************************************************************
  *   Copyright (C) 2004 by Roberto Virga                                   *
- *   rvirga@users.sf.net                                                   *
+ *   rvirga@users.sourceforge.net                                          *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
+ *   it under the terms of the GNU Library General Public License as       *
+ *   published by the Free Software Foundation; either version 2 of the    *
+ *   License, or (at your option) any later version.                       *
  *                                                                         *
  *   This program is distributed in the hope that it will be useful,       *
  *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
  *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
  *   GNU General Public License for more details.                          *
  *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program; if not, write to the                         *
+ *   You should have received a copy of the GNU Library General Public     *
+ *   License along with this program; if not, write to the                 *
  *   Free Software Foundation, Inc.,                                       *
  *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
  ***************************************************************************/
@@ -25,7 +25,9 @@
 
 #include "kbssetilog.h"
 
-const QString KBSSETILog::s_filename[] = {"SETILog.csv", "SETIResult.log"};
+using namespace KBSBOINC;
+
+const QString KBSSETILog::s_filename[] = {"KBSSETILog.csv", "KBSSETIResult.log"};
 
 KBSSETILog::KBSSETILog(const KURL &url, QObject *parent, const char *name)
           : KBSLogMonitor(url, parent, name), m_count(0)
@@ -69,13 +71,13 @@ KBSLogDatum KBSSETILog::formatWorkunitDatum(KBSSETIProjectMonitor *projectMonito
 {
   const QString project = projectMonitor->project();
   const KBSBOINCMonitor *boincMonitor =  projectMonitor->boincMonitor();
-  const BOINCClientState *state = boincMonitor->state();
+  const KBSBOINCClientState *state = boincMonitor->state();
   if(NULL == state) return KBSLogDatum();
   
   QString app_filename;
   const QString app_name = state->workunit[workunit].app_name;
   const unsigned version_num = state->workunit[workunit].version_num;
-  for(BOINCAppVersionList::const_iterator it = state->app_version[app_name].begin();
+  for(KBSBOINCAppVersionList::const_iterator it = state->app_version[app_name].begin();
       it != state->app_version[app_name].end(); ++it)
     if((*it).version_num == version_num) {
       if(!(*it).file_ref.isEmpty())
@@ -85,7 +87,7 @@ KBSLogDatum KBSSETILog::formatWorkunitDatum(KBSSETIProjectMonitor *projectMonito
   
   const QString result = state->workunit[workunit].result_name;
   
-  const SETIResult *datum = projectMonitor->result(workunit);
+  const KBSSETIResult *datum = projectMonitor->result(workunit);
   if(NULL == datum) return KBSLogDatum();
 
   KBSLogDatum out;
@@ -187,20 +189,20 @@ KBSLogDatum KBSSETILog::formatWorkunitDatum(KBSSETIProjectMonitor *projectMonito
 KBSLogData KBSSETILog::formatSpikeData(KBSSETIProjectMonitor *projectMonitor,
                                        const QString &workunit) const
 {
-  const BOINCClientState *state = projectMonitor->boincMonitor()->state();
+  const KBSBOINCClientState *state = projectMonitor->boincMonitor()->state();
   if(NULL == state) return KBSLogData();
   
-  const SETIResult *datum = projectMonitor->result(workunit);
+  const KBSSETIResult *datum = projectMonitor->result(workunit);
   if(NULL == datum) return KBSLogData();
   
   KBSLogData out;
   unsigned index = 1;
-  for(QValueList<SETISpike>::const_iterator it = datum->spike.constBegin();
+  for(QValueList<KBSSETISpike>::const_iterator it = datum->spike.constBegin();
       it != datum->spike.constEnd(); ++it)
   {
     KBSLogDatum spike;
     
-    spike["type"] = SETISpike::type;
+    spike["type"] = KBSSETISpike::type;
     spike["workunit"] = workunit;
     spike["index"] = index++;
     spike["last"] = false;
@@ -222,20 +224,20 @@ KBSLogData KBSSETILog::formatSpikeData(KBSSETIProjectMonitor *projectMonitor,
 KBSLogData KBSSETILog::formatGaussianData(KBSSETIProjectMonitor *projectMonitor,
                                           const QString &workunit) const
 {
-  const BOINCClientState *state = projectMonitor->boincMonitor()->state();
+  const KBSBOINCClientState *state = projectMonitor->boincMonitor()->state();
   if(NULL == state) return KBSLogData();
   
-  const SETIResult *datum = projectMonitor->result(workunit);
+  const KBSSETIResult *datum = projectMonitor->result(workunit);
   if(NULL == datum) return KBSLogData();
   
   KBSLogData out;
   unsigned index = 1;
-  for(QValueList<SETIGaussian>::const_iterator it = datum->gaussian.constBegin();
+  for(QValueList<KBSSETIGaussian>::const_iterator it = datum->gaussian.constBegin();
       it != datum->gaussian.constEnd(); ++it)
   {
     KBSLogDatum gaussian;
     
-    gaussian["type"] = SETIGaussian::type;
+    gaussian["type"] = KBSSETIGaussian::type;
     gaussian["workunit"] = workunit;
     gaussian["index"] = index++;
     gaussian["last"] = false;
@@ -263,20 +265,20 @@ KBSLogData KBSSETILog::formatGaussianData(KBSSETIProjectMonitor *projectMonitor,
 KBSLogData KBSSETILog::formatPulseData(KBSSETIProjectMonitor *projectMonitor,
                                        const QString &workunit) const
 {
-  const BOINCClientState *state = projectMonitor->boincMonitor()->state();
+  const KBSBOINCClientState *state = projectMonitor->boincMonitor()->state();
   if(NULL == state) return KBSLogData();
   
-  const SETIResult *datum = projectMonitor->result(workunit);
+  const KBSSETIResult *datum = projectMonitor->result(workunit);
   if(NULL == datum) return KBSLogData();
   
   KBSLogData out;
   unsigned index = 1;
-  for(QValueList<SETIPulse>::const_iterator it = datum->pulse.constBegin();
+  for(QValueList<KBSSETIPulse>::const_iterator it = datum->pulse.constBegin();
       it != datum->pulse.constEnd(); ++it)
   {
     KBSLogDatum pulse;
     
-    pulse["type"] = SETIPulse::type;
+    pulse["type"] = KBSSETIPulse::type;
     pulse["workunit"] = workunit;
     pulse["index"] = index++;
     pulse["last"] = false;
@@ -305,20 +307,20 @@ KBSLogData KBSSETILog::formatPulseData(KBSSETIProjectMonitor *projectMonitor,
 KBSLogData KBSSETILog::formatTripletData(KBSSETIProjectMonitor *projectMonitor,
                                          const QString &workunit) const
 {
-  const BOINCClientState *state = projectMonitor->boincMonitor()->state();
+  const KBSBOINCClientState *state = projectMonitor->boincMonitor()->state();
   if(NULL == state) return KBSLogData();
   
-  const SETIResult *datum = projectMonitor->result(workunit);
+  const KBSSETIResult *datum = projectMonitor->result(workunit);
   if(NULL == datum) return KBSLogData();
   
   KBSLogData out;
   unsigned index = 1;
-  for(QValueList<SETITriplet>::const_iterator it = datum->triplet.constBegin();
+  for(QValueList<KBSSETITriplet>::const_iterator it = datum->triplet.constBegin();
       it != datum->triplet.constEnd(); ++it)
   {
     KBSLogDatum triplet;
     
-    triplet["type"] = SETITriplet::type;
+    triplet["type"] = KBSSETITriplet::type;
     triplet["workunit"] = workunit;
     triplet["index"] = index++;
     triplet["last"] = false;
@@ -385,7 +387,7 @@ void KBSSETILog::appendResult(QIODevice *io, const KBSLogDatum &datum)
     text << "[" << m_workunit << "]" << "\r\n";
   }
 
-  if(datum["type"].toString() == SETISpike::type)
+  if(datum["type"].toString() == KBSSETISpike::type)
   {
     text << "spike" << QString::number(datum["index"].toUInt()).rightJustify(2, '0') << "=";
 
@@ -399,7 +401,7 @@ void KBSSETILog::appendResult(QIODevice *io, const KBSLogDatum &datum)
     
     text << "\r\n";
   }
-  else if(datum["type"].toString() == SETIGaussian::type)
+  else if(datum["type"].toString() == KBSSETIGaussian::type)
   {
     text << "gaussian" << QString::number(datum["index"].toUInt()).rightJustify(2, '0') << "=";
 
@@ -418,7 +420,7 @@ void KBSSETILog::appendResult(QIODevice *io, const KBSLogDatum &datum)
   
     text << "\r\n";
   }
-  else if(datum["type"].toString() == SETIPulse::type)
+  else if(datum["type"].toString() == KBSSETIPulse::type)
   {
     text << "pulse" << QString::number(datum["index"].toUInt()).rightJustify(2, '0') << "=";
 
@@ -438,7 +440,7 @@ void KBSSETILog::appendResult(QIODevice *io, const KBSLogDatum &datum)
     
     text << "\r\n";
   }
-  else if(datum["type"].toString() == SETIPulse::type)
+  else if(datum["type"].toString() == KBSSETIPulse::type)
   {
     text << "triplet" << QString::number(datum["index"].toUInt()).rightJustify(2, '0') << "=";
 
@@ -567,10 +569,10 @@ bool KBSSETILog::parseResultsLogDocument(const QStringList &lines)
       if(eq >= 0)
       {
         KBSLogDatum datum = parseKVPSequence((*line).mid(eq+1));
-        datum["type"] = (*line).startsWith("spike")    ? SETISpike::type
-                      : (*line).startsWith("gaussian") ? SETIGaussian::type
-                      : (*line).startsWith("pulse")    ? SETIPulse::type
-                                                       : SETITriplet::type;
+        datum["type"] = (*line).startsWith("spike")    ? KBSSETISpike::type
+                      : (*line).startsWith("gaussian") ? KBSSETIGaussian::type
+                      : (*line).startsWith("pulse")    ? KBSSETIPulse::type
+                                                       : KBSSETITriplet::type;
       
         m_results[workunit] << datum;
       }
