@@ -1,19 +1,19 @@
 /***************************************************************************
  *   Copyright (C) 2004 by Roberto Virga                                   *
- *   rvirga@users.sf.net                                                   *
+ *   rvirga@users.sourceforge.net                                          *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
+ *   it under the terms of the GNU Library General Public License as       *
+ *   published by the Free Software Foundation; either version 2 of the    *
+ *   License, or (at your option) any later version.                       *
  *                                                                         *
  *   This program is distributed in the hope that it will be useful,       *
  *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
  *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
  *   GNU General Public License for more details.                          *
  *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program; if not, write to the                         *
+ *   You should have received a copy of the GNU Library General Public     *
+ *   License along with this program; if not, write to the                 *
  *   Free Software Foundation, Inc.,                                       *
  *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
  ***************************************************************************/
@@ -23,6 +23,8 @@
 
 #include "kbssetilog9x.h"
 
+using namespace KBSBOINC;
+
 const QString KBSSETILog9x::s_filename[] =
   {"log9x.csv", "spikelog.csv", "gaussianlog.csv", "pulselog.csv", "tripletlog.csv"};
 
@@ -72,13 +74,13 @@ KBSLogDatum KBSSETILog9x::formatWorkunitDatum(KBSSETIProjectMonitor *projectMoni
 {
   const QString project = projectMonitor->project();
   const KBSBOINCMonitor *boincMonitor =  projectMonitor->boincMonitor();
-  const BOINCClientState *state = boincMonitor->state();
+  const KBSBOINCClientState *state = boincMonitor->state();
   if(NULL == state) return KBSLogDatum();
   
   QString app_filename;
   const QString app_name = state->workunit[workunit].app_name;
   const unsigned version_num = state->workunit[workunit].version_num;
-  for(BOINCAppVersionList::const_iterator it = state->app_version[app_name].begin();
+  for(KBSBOINCAppVersionList::const_iterator it = state->app_version[app_name].begin();
       it != state->app_version[app_name].end(); ++it)
     if((*it).version_num == version_num) {
       if(!(*it).file_ref.isEmpty())
@@ -88,7 +90,7 @@ KBSLogDatum KBSSETILog9x::formatWorkunitDatum(KBSSETIProjectMonitor *projectMoni
   
   const QString result = state->workunit[workunit].result_name;
   
-  const SETIResult *datum = projectMonitor->result(workunit);
+  const KBSSETIResult *datum = projectMonitor->result(workunit);
   if(NULL == datum) return KBSLogDatum();
 
   KBSLogDatum out;
@@ -182,16 +184,16 @@ KBSLogData KBSSETILog9x::formatSpikeData(KBSSETIProjectMonitor *projectMonitor,
                                          const QString &workunit) const
 {
   const KBSBOINCMonitor *boincMonitor =  projectMonitor->boincMonitor();
-  const BOINCClientState *state = boincMonitor->state();
+  const KBSBOINCClientState *state = boincMonitor->state();
   if(NULL == state) return KBSLogData();
   
   const QString result = state->workunit[workunit].result_name;
   
-  const SETIResult *datum = projectMonitor->result(workunit);
+  const KBSSETIResult *datum = projectMonitor->result(workunit);
   if(NULL == datum) return KBSLogData();
   
   KBSLogData out;
-  for(QValueList<SETISpike>::const_iterator it = datum->spike.constBegin();
+  for(QValueList<KBSSETISpike>::const_iterator it = datum->spike.constBegin();
       it != datum->spike.constEnd(); ++it)
   {
     KBSLogDatum spike;
@@ -215,16 +217,16 @@ KBSLogData KBSSETILog9x::formatGaussianData(KBSSETIProjectMonitor *projectMonito
                                             const QString &workunit) const
 {
   const KBSBOINCMonitor *boincMonitor =  projectMonitor->boincMonitor();
-  const BOINCClientState *state = boincMonitor->state();
+  const KBSBOINCClientState *state = boincMonitor->state();
   if(NULL == state) return KBSLogData();
   
   const QString result = state->workunit[workunit].result_name;
   
-  const SETIResult *datum = projectMonitor->result(workunit);
+  const KBSSETIResult *datum = projectMonitor->result(workunit);
   if(NULL == datum) return KBSLogData();
   
   KBSLogData out;
-  for(QValueList<SETIGaussian>::const_iterator it = datum->gaussian.constBegin();
+  for(QValueList<KBSSETIGaussian>::const_iterator it = datum->gaussian.constBegin();
       it != datum->gaussian.constEnd(); ++it)
   {
     KBSLogDatum gaussian;
@@ -254,16 +256,16 @@ KBSLogData KBSSETILog9x::formatPulseData(KBSSETIProjectMonitor *projectMonitor,
                                          const QString &workunit) const
 {
   const KBSBOINCMonitor *boincMonitor =  projectMonitor->boincMonitor();
-  const BOINCClientState *state = boincMonitor->state();
+  const KBSBOINCClientState *state = boincMonitor->state();
   if(NULL == state) return KBSLogData();
   
   const QString result = state->workunit[workunit].result_name;
   
-  const SETIResult *datum = projectMonitor->result(workunit);
+  const KBSSETIResult *datum = projectMonitor->result(workunit);
   if(NULL == datum) return KBSLogData();
   
   KBSLogData out;
-  for(QValueList<SETIPulse>::const_iterator it = datum->pulse.constBegin();
+  for(QValueList<KBSSETIPulse>::const_iterator it = datum->pulse.constBegin();
       it != datum->pulse.constEnd(); ++it)
   {
     KBSLogDatum pulse;
@@ -294,16 +296,16 @@ KBSLogData KBSSETILog9x::formatTripletData(KBSSETIProjectMonitor *projectMonitor
                                            const QString &workunit) const
 {
   const KBSBOINCMonitor *boincMonitor =  projectMonitor->boincMonitor();
-  const BOINCClientState *state = boincMonitor->state();
+  const KBSBOINCClientState *state = boincMonitor->state();
   if(NULL == state) return KBSLogData();
   
   const QString result = state->workunit[workunit].result_name;
   
-  const SETIResult *datum = projectMonitor->result(workunit);
+  const KBSSETIResult *datum = projectMonitor->result(workunit);
   if(NULL == datum) return KBSLogData();
   
   KBSLogData out;
-  for(QValueList<SETITriplet>::const_iterator it = datum->triplet.constBegin();
+  for(QValueList<KBSSETITriplet>::const_iterator it = datum->triplet.constBegin();
       it != datum->triplet.constEnd(); ++it)
   {
     KBSLogDatum triplet;
@@ -473,18 +475,18 @@ bool KBSSETILog9x::parseResultsLogDocument(unsigned type, const QStringList &lin
     datum["time"] = parseJulianDate(datum["time"].toDouble());
     switch(type) {
       case Spike:
-        datum["type"] = SETISpike::type;
+        datum["type"] = KBSSETISpike::type;
         break;
       case Gaussian:
-        datum["type"] = SETIGaussian::type;
+        datum["type"] = KBSSETIGaussian::type;
         datum["pot"] = parsePotData(datum["pot"].toString());
         break;
       case Pulse:
-        datum["type"] = SETIPulse::type;
+        datum["type"] = KBSSETIPulse::type;
         datum["prof"] = parsePotData(datum["prof"].toString());
         break;
       case Triplet:
-        datum["type"] = SETITriplet::type;
+        datum["type"] = KBSSETITriplet::type;
     }
     
     m_results[workunit] << datum;
