@@ -1,19 +1,19 @@
 /***************************************************************************
  *   Copyright (C) 2004 by Roberto Virga                                   *
- *   rvirga@users.sf.net                                                   *
+ *   rvirga@users.sourceforge.net                                          *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
+ *   it under the terms of the GNU Library General Public License as       *
+ *   published by the Free Software Foundation; either version 2 of the    *
+ *   License, or (at your option) any later version.                       *
  *                                                                         *
  *   This program is distributed in the hope that it will be useful,       *
  *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
  *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
  *   GNU General Public License for more details.                          *
  *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program; if not, write to the                         *
+ *   You should have received a copy of the GNU Library General Public     *
+ *   License along with this program; if not, write to the                 *
  *   Free Software Foundation, Inc.,                                       *
  *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
  ***************************************************************************/
@@ -21,15 +21,17 @@
 #include <math.h>
 
 #include <qtextstream.h>
- 
-#include <setidata.h>
-#include <boincdata.h>
+
+#include <kbssetidata.h>
+#include <kbsboincdata.h>
 
 #include <kbsboincmonitor.h>
 #include <kbssetiprojectmonitor.h>
 
 #include "kbssetilogx.h"
 
+using namespace KBSBOINC;
+
 const QString KBSSETILogX::s_version = "1.11";
 const QString KBSSETILogX::s_filename[] =
   {"sah_boinc.csv",
@@ -81,12 +83,12 @@ KBSLogDatum KBSSETILogX::formatWorkunitDatum(KBSSETIProjectMonitor *projectMonit
 {
   const QString project = projectMonitor->project();
   const KBSBOINCMonitor *boincMonitor =  projectMonitor->boincMonitor();
-  const BOINCClientState *state = boincMonitor->state();
+  const KBSBOINCClientState *state = boincMonitor->state();
   if(NULL == state) return KBSLogDatum();
   
   const QString result = state->workunit[workunit].result_name;
   
-  const SETIResult *datum = projectMonitor->result(workunit);
+  const KBSSETIResult *datum = projectMonitor->result(workunit);
   if(NULL == datum) return KBSLogDatum();
   
   KBSLogDatum out;
@@ -202,16 +204,16 @@ KBSLogDatum KBSSETILogX::formatWorkunitDatum(KBSSETIProjectMonitor *projectMonit
 KBSLogData KBSSETILogX::formatSpikeData(KBSSETIProjectMonitor *projectMonitor,
                                         const QString &workunit) const
 {
-  const BOINCClientState *state = projectMonitor->boincMonitor()->state();
+  const KBSBOINCClientState *state = projectMonitor->boincMonitor()->state();
   if(NULL == state) return KBSLogData();
   
   const QString result = state->workunit[workunit].result_name;
   
-  const SETIResult *datum = projectMonitor->result(workunit);
+  const KBSSETIResult *datum = projectMonitor->result(workunit);
   if(NULL == datum) return KBSLogData();
   
   KBSLogData out;
-  for(QValueList<SETISpike>::const_iterator it = datum->spike.constBegin();
+  for(QValueList<KBSSETISpike>::const_iterator it = datum->spike.constBegin();
       it != datum->spike.constEnd(); ++it)
   {
     KBSLogDatum spike;
@@ -237,16 +239,16 @@ KBSLogData KBSSETILogX::formatSpikeData(KBSSETIProjectMonitor *projectMonitor,
 KBSLogData KBSSETILogX::formatGaussianData(KBSSETIProjectMonitor *projectMonitor,
                                            const QString &workunit) const
 {
-  const BOINCClientState *state = projectMonitor->boincMonitor()->state();
+  const KBSBOINCClientState *state = projectMonitor->boincMonitor()->state();
   if(NULL == state) return KBSLogData();
   
   const QString result = state->workunit[workunit].result_name;
   
-  const SETIResult *datum = projectMonitor->result(workunit);
+  const KBSSETIResult *datum = projectMonitor->result(workunit);
   if(NULL == datum) return KBSLogData();
   
   KBSLogData out;
-  for(QValueList<SETIGaussian>::const_iterator it = datum->gaussian.constBegin();
+  for(QValueList<KBSSETIGaussian>::const_iterator it = datum->gaussian.constBegin();
       it != datum->gaussian.constEnd(); ++it)
   {
     KBSLogDatum gaussian;
@@ -278,16 +280,16 @@ KBSLogData KBSSETILogX::formatGaussianData(KBSSETIProjectMonitor *projectMonitor
 KBSLogData KBSSETILogX::formatPulseData(KBSSETIProjectMonitor *projectMonitor,
                                         const QString &workunit) const
 {
-  const BOINCClientState *state = projectMonitor->boincMonitor()->state();
+  const KBSBOINCClientState *state = projectMonitor->boincMonitor()->state();
   if(NULL == state) return KBSLogData();
   
   const QString result = state->workunit[workunit].result_name;
   
-  const SETIResult *datum = projectMonitor->result(workunit);
+  const KBSSETIResult *datum = projectMonitor->result(workunit);
   if(NULL == datum) return KBSLogData();
   
   KBSLogData out;
-  for(QValueList<SETIPulse>::const_iterator it = datum->pulse.constBegin();
+  for(QValueList<KBSSETIPulse>::const_iterator it = datum->pulse.constBegin();
       it != datum->pulse.constEnd(); ++it)
   {
     KBSLogDatum pulse;
@@ -320,16 +322,16 @@ KBSLogData KBSSETILogX::formatPulseData(KBSSETIProjectMonitor *projectMonitor,
 KBSLogData KBSSETILogX::formatTripletData(KBSSETIProjectMonitor *projectMonitor,
                                           const QString &workunit) const
 {
-  const BOINCClientState *state = projectMonitor->boincMonitor()->state();
+  const KBSBOINCClientState *state = projectMonitor->boincMonitor()->state();
   if(NULL == state) return KBSLogData();
   
   const QString result = state->workunit[workunit].result_name;
   
-  const SETIResult *datum = projectMonitor->result(workunit);
+  const KBSSETIResult *datum = projectMonitor->result(workunit);
   if(NULL == datum) return KBSLogData();
   
   KBSLogData out;
-  for(QValueList<SETITriplet>::const_iterator it = datum->triplet.constBegin();
+  for(QValueList<KBSSETITriplet>::const_iterator it = datum->triplet.constBegin();
       it != datum->triplet.constEnd(); ++it)
   {
     KBSLogDatum triplet;
@@ -501,18 +503,18 @@ bool KBSSETILogX::parseResultsLogDocument(unsigned type, const QStringList &line
     datum["time"] = parseJulianDate(datum["time"].toDouble());
     switch(type) {
       case Spike:
-        datum["type"] = SETISpike::type;
+        datum["type"] = KBSSETISpike::type;
         break;
       case Gaussian:
-        datum["type"] = SETIGaussian::type;
+        datum["type"] = KBSSETIGaussian::type;
         datum["pot"] = parsePotData(datum["pot"].toString());
         break;
       case Pulse:
-        datum["type"] = SETIPulse::type;
+        datum["type"] = KBSSETIPulse::type;
         datum["prof"] = parsePotData(datum["prof"].toString());
         break;
       case Triplet:
-        datum["type"] = SETITriplet::type;
+        datum["type"] = KBSSETITriplet::type;
     }
     
     m_results[workunit] << datum;
