@@ -1,19 +1,19 @@
 /***************************************************************************
  *   Copyright (C) 2004 by Roberto Virga                                   *
- *   rvirga@users.sf.net                                                   *
+ *   rvirga@users.sourceforge.net                                          *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
+ *   it under the terms of the GNU Library General Public License as       *
+ *   published by the Free Software Foundation; either version 2 of the    *
+ *   License, or (at your option) any later version.                       *
  *                                                                         *
  *   This program is distributed in the hope that it will be useful,       *
  *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
  *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
  *   GNU General Public License for more details.                          *
  *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program; if not, write to the                         *
+ *   You should have received a copy of the GNU Library General Public     *
+ *   License along with this program; if not, write to the                 *
  *   Free Software Foundation, Inc.,                                       *
  *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
  ***************************************************************************/
@@ -40,6 +40,8 @@
 
 #include "kbssetiskymapwindow.h"
 
+using namespace KBSSETI;
+
 KBSSETISkyMapTarget::KBSSETISkyMapTarget(const QString &workunit, QWidget *parent)
                    : QLabel(parent), m_workunit(workunit)
 {
@@ -81,8 +83,10 @@ void KBSSETISkyMapTarget::removeProjectMonitor(KBSSETIProjectMonitor *projectMon
     if(NULL != projectMonitor) {
       connectProjectMonitor(projectMonitor);
       update();
-    } else
+    } else {
       KBSSETISkyMapWindow::self()->m_targets.remove(m_workunit);
+      destroy();
+    }
   }
 }
 
@@ -115,10 +119,10 @@ void KBSSETISkyMapTarget::update()
   
   if(NULL != projectMonitor)
   {
-    const SETIResult *setiResult = projectMonitor->result(m_workunit);
+    const KBSSETIResult *setiResult = projectMonitor->result(m_workunit);
     
     KBSBOINCMonitor *boincMonitor = projectMonitor->boincMonitor();
-    const BOINCClientState *state = boincMonitor->state();
+    const KBSBOINCClientState *state = boincMonitor->state();
     QString result = (NULL != state) ? state->workunit[m_workunit].result_name : QString::null;
     const int task = !result.isEmpty() ? state->active_task_set.index(result) : -1;
     
@@ -126,11 +130,11 @@ void KBSSETISkyMapTarget::update()
     {
       KLocale *locale = KGlobal::locale();
       
-      const SETIGroupInfo *group_info = &(setiResult->workunit_header.group_info);
-      const double ra = group_info->data_desc.start.ra;
-      const double dec = group_info->data_desc.start.dec;
-      const double ar = group_info->data_desc.true_angle_range;
-      const double teraFLOPs = group_info->data_desc.teraFLOPs();
+      const KBSSETIGroupInfo &group_info = setiResult->workunit_header.group_info;
+      const double ra = group_info.data_desc.start.ra;
+      const double dec = group_info.data_desc.start.dec;
+      const double ar = group_info.data_desc.true_angle_range;
+      const double teraFLOPs = group_info.data_desc.teraFLOPs();
       
       QSize size;
       if(NULL != state && task >= 0 && state->active_task_set.active_task[task].scheduler_state > 1)
@@ -356,9 +360,6 @@ KBSSETISkyMapWindow::KBSSETISkyMapWindow(QWidget *parent, const char *name)
   
   scrollView->addChild(m_view);
   
-  m_targets.setAutoDelete(true);
-  m_history.setAutoDelete(true);
-  
   KBSSETILogManager *logManager = KBSSETILogManager::self();
   connect(logManager, SIGNAL(logChanged()), this, SLOT(buildHistory()));
   connect(logManager, SIGNAL(workunitsUpdated()), this, SLOT(updateHistory()));
@@ -428,7 +429,7 @@ void KBSSETISkyMapWindow::setHistoryVisible(bool visible)
     if(visible) label->show();
     else label->hide();
 }
-    
+
 void KBSSETISkyMapWindow::addWorkunit(KBSSETIProjectMonitor *projectMonitor, const QString &workunit)
 {
   KBSSETISkyMapTarget *target = m_targets.find(workunit);
@@ -448,7 +449,7 @@ void KBSSETISkyMapWindow::removeWorkunit(KBSSETIProjectMonitor *projectMonitor,
   target->removeProjectMonitor(projectMonitor);
   
   if(m_targets.isEmpty())
-  {    
+  {
     m_legend->close();
     close();
     
@@ -482,7 +483,10 @@ double KBSSETISkyMapWindow::distance(const double ra1, const double dec1, const
 
 void KBSSETISkyMapWindow::buildHistory()
 {
+  for(QLabel *label = m_history.first(); label != NULL; label = m_history.next())
+    delete label;
   m_history.clear();
+  
   updateHistory();
 }
 
@@ -535,7 +539,7 @@ void KBSSETISkyMapWindow::updateHistory()
     if((*it).contains("angle_range"))
     {
       const double ar = (*it)["angle_range"].toDouble();
-      teraFLOPs = SETIDataDesc::teraFLOPs(ar);
+      teraFLOPs = KBSSETIDataDesc::teraFLOPs(ar);
       
       tooltip << i18n("Angle Range: %1 (%2 TeraFLOPs)")
                    .arg(locale->formatNumber(ar, 3))
